// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_UI_Composition_Effects_1_H
#define WINRT_Windows_UI_Composition_Effects_1_H
#include "winrt/impl/Windows.UI.Composition.Effects.0.h"
WINRT_EXPORT namespace winrt::Windows::UI::Composition::Effects
{
    struct WINRT_IMPL_EMPTY_BASES ISceneLightingEffect :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISceneLightingEffect>
    {
        ISceneLightingEffect(std::nullptr_t = nullptr) noexcept {}
        ISceneLightingEffect(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISceneLightingEffect2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISceneLightingEffect2>
    {
        ISceneLightingEffect2(std::nullptr_t = nullptr) noexcept {}
        ISceneLightingEffect2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
