# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Activation")

try:
    import winsdk.windows.applicationmodel.appointments.appointmentsprovider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.background
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.calls
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts.provider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.datatransfer.sharetarget
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.search
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.userdataaccounts.provider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.wallet
except ImportError:
    pass

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.devices.printers.extensions
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.speechrecognition
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.pickers.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage.search
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.notifications
except ImportError:
    pass

try:
    import winsdk.windows.ui.viewmanagement
except ImportError:
    pass

class ActivationKind(enum.IntEnum):
    LAUNCH = 0
    SEARCH = 1
    SHARE_TARGET = 2
    FILE = 3
    PROTOCOL = 4
    FILE_OPEN_PICKER = 5
    FILE_SAVE_PICKER = 6
    CACHED_FILE_UPDATER = 7
    CONTACT_PICKER = 8
    DEVICE = 9
    PRINT_TASK_SETTINGS = 10
    CAMERA_SETTINGS = 11
    RESTRICTED_LAUNCH = 12
    APPOINTMENTS_PROVIDER = 13
    CONTACT = 14
    LOCK_SCREEN_CALL = 15
    VOICE_COMMAND = 16
    LOCK_SCREEN = 17
    PICKER_RETURNED = 1000
    WALLET_ACTION = 1001
    PICK_FILE_CONTINUATION = 1002
    PICK_SAVE_FILE_CONTINUATION = 1003
    PICK_FOLDER_CONTINUATION = 1004
    WEB_AUTHENTICATION_BROKER_CONTINUATION = 1005
    WEB_ACCOUNT_PROVIDER = 1006
    COMPONENT_U_I = 1007
    PROTOCOL_FOR_RESULTS = 1009
    TOAST_NOTIFICATION = 1010
    PRINT3_D_WORKFLOW = 1011
    DIAL_RECEIVER = 1012
    DEVICE_PAIRING = 1013
    USER_DATA_ACCOUNTS_PROVIDER = 1014
    FILE_PICKER_EXPERIENCE = 1015
    LOCK_SCREEN_COMPONENT = 1016
    CONTACT_PANEL = 1017
    PRINT_WORKFLOW_FOREGROUND_TASK = 1018
    GAME_U_I_PROVIDER = 1019
    STARTUP_TASK = 1020
    COMMAND_LINE_LAUNCH = 1021
    BARCODE_SCANNER_PROVIDER = 1022
    PRINT_SUPPORT_JOB_U_I = 1023
    PRINT_SUPPORT_SETTINGS_U_I = 1024
    PHONE_CALL_ACTIVATION = 1025
    VPN_FOREGROUND = 1026

class ApplicationExecutionState(enum.IntEnum):
    NOT_RUNNING = 0
    RUNNING = 1
    SUSPENDED = 2
    TERMINATED = 3
    CLOSED_BY_USER = 4

_ns_module._register_ActivationKind(ActivationKind)
_ns_module._register_ApplicationExecutionState(ApplicationExecutionState)

AppointmentsProviderAddAppointmentActivatedEventArgs = _ns_module.AppointmentsProviderAddAppointmentActivatedEventArgs
AppointmentsProviderRemoveAppointmentActivatedEventArgs = _ns_module.AppointmentsProviderRemoveAppointmentActivatedEventArgs
AppointmentsProviderReplaceAppointmentActivatedEventArgs = _ns_module.AppointmentsProviderReplaceAppointmentActivatedEventArgs
AppointmentsProviderShowAppointmentDetailsActivatedEventArgs = _ns_module.AppointmentsProviderShowAppointmentDetailsActivatedEventArgs
AppointmentsProviderShowTimeFrameActivatedEventArgs = _ns_module.AppointmentsProviderShowTimeFrameActivatedEventArgs
BackgroundActivatedEventArgs = _ns_module.BackgroundActivatedEventArgs
BarcodeScannerPreviewActivatedEventArgs = _ns_module.BarcodeScannerPreviewActivatedEventArgs
CachedFileUpdaterActivatedEventArgs = _ns_module.CachedFileUpdaterActivatedEventArgs
CameraSettingsActivatedEventArgs = _ns_module.CameraSettingsActivatedEventArgs
CommandLineActivatedEventArgs = _ns_module.CommandLineActivatedEventArgs
CommandLineActivationOperation = _ns_module.CommandLineActivationOperation
ContactCallActivatedEventArgs = _ns_module.ContactCallActivatedEventArgs
ContactMapActivatedEventArgs = _ns_module.ContactMapActivatedEventArgs
ContactMessageActivatedEventArgs = _ns_module.ContactMessageActivatedEventArgs
ContactPanelActivatedEventArgs = _ns_module.ContactPanelActivatedEventArgs
ContactPickerActivatedEventArgs = _ns_module.ContactPickerActivatedEventArgs
ContactPostActivatedEventArgs = _ns_module.ContactPostActivatedEventArgs
ContactVideoCallActivatedEventArgs = _ns_module.ContactVideoCallActivatedEventArgs
DeviceActivatedEventArgs = _ns_module.DeviceActivatedEventArgs
DevicePairingActivatedEventArgs = _ns_module.DevicePairingActivatedEventArgs
DialReceiverActivatedEventArgs = _ns_module.DialReceiverActivatedEventArgs
FileActivatedEventArgs = _ns_module.FileActivatedEventArgs
FileOpenPickerActivatedEventArgs = _ns_module.FileOpenPickerActivatedEventArgs
FileOpenPickerContinuationEventArgs = _ns_module.FileOpenPickerContinuationEventArgs
FileSavePickerActivatedEventArgs = _ns_module.FileSavePickerActivatedEventArgs
FileSavePickerContinuationEventArgs = _ns_module.FileSavePickerContinuationEventArgs
FolderPickerContinuationEventArgs = _ns_module.FolderPickerContinuationEventArgs
LaunchActivatedEventArgs = _ns_module.LaunchActivatedEventArgs
LockScreenActivatedEventArgs = _ns_module.LockScreenActivatedEventArgs
LockScreenCallActivatedEventArgs = _ns_module.LockScreenCallActivatedEventArgs
LockScreenComponentActivatedEventArgs = _ns_module.LockScreenComponentActivatedEventArgs
PhoneCallActivatedEventArgs = _ns_module.PhoneCallActivatedEventArgs
PickerReturnedActivatedEventArgs = _ns_module.PickerReturnedActivatedEventArgs
Print3DWorkflowActivatedEventArgs = _ns_module.Print3DWorkflowActivatedEventArgs
PrintTaskSettingsActivatedEventArgs = _ns_module.PrintTaskSettingsActivatedEventArgs
ProtocolActivatedEventArgs = _ns_module.ProtocolActivatedEventArgs
ProtocolForResultsActivatedEventArgs = _ns_module.ProtocolForResultsActivatedEventArgs
RestrictedLaunchActivatedEventArgs = _ns_module.RestrictedLaunchActivatedEventArgs
SearchActivatedEventArgs = _ns_module.SearchActivatedEventArgs
ShareTargetActivatedEventArgs = _ns_module.ShareTargetActivatedEventArgs
SplashScreen = _ns_module.SplashScreen
StartupTaskActivatedEventArgs = _ns_module.StartupTaskActivatedEventArgs
TileActivatedInfo = _ns_module.TileActivatedInfo
ToastNotificationActivatedEventArgs = _ns_module.ToastNotificationActivatedEventArgs
UserDataAccountProviderActivatedEventArgs = _ns_module.UserDataAccountProviderActivatedEventArgs
VoiceCommandActivatedEventArgs = _ns_module.VoiceCommandActivatedEventArgs
WalletActionActivatedEventArgs = _ns_module.WalletActionActivatedEventArgs
WebAccountProviderActivatedEventArgs = _ns_module.WebAccountProviderActivatedEventArgs
WebAuthenticationBrokerContinuationEventArgs = _ns_module.WebAuthenticationBrokerContinuationEventArgs
IActivatedEventArgs = _ns_module.IActivatedEventArgs
IActivatedEventArgsWithUser = _ns_module.IActivatedEventArgsWithUser
IApplicationViewActivatedEventArgs = _ns_module.IApplicationViewActivatedEventArgs
IAppointmentsProviderActivatedEventArgs = _ns_module.IAppointmentsProviderActivatedEventArgs
IAppointmentsProviderAddAppointmentActivatedEventArgs = _ns_module.IAppointmentsProviderAddAppointmentActivatedEventArgs
IAppointmentsProviderRemoveAppointmentActivatedEventArgs = _ns_module.IAppointmentsProviderRemoveAppointmentActivatedEventArgs
IAppointmentsProviderReplaceAppointmentActivatedEventArgs = _ns_module.IAppointmentsProviderReplaceAppointmentActivatedEventArgs
IAppointmentsProviderShowAppointmentDetailsActivatedEventArgs = _ns_module.IAppointmentsProviderShowAppointmentDetailsActivatedEventArgs
IAppointmentsProviderShowTimeFrameActivatedEventArgs = _ns_module.IAppointmentsProviderShowTimeFrameActivatedEventArgs
IBackgroundActivatedEventArgs = _ns_module.IBackgroundActivatedEventArgs
IBarcodeScannerPreviewActivatedEventArgs = _ns_module.IBarcodeScannerPreviewActivatedEventArgs
ICachedFileUpdaterActivatedEventArgs = _ns_module.ICachedFileUpdaterActivatedEventArgs
ICameraSettingsActivatedEventArgs = _ns_module.ICameraSettingsActivatedEventArgs
ICommandLineActivatedEventArgs = _ns_module.ICommandLineActivatedEventArgs
IContactActivatedEventArgs = _ns_module.IContactActivatedEventArgs
IContactCallActivatedEventArgs = _ns_module.IContactCallActivatedEventArgs
IContactMapActivatedEventArgs = _ns_module.IContactMapActivatedEventArgs
IContactMessageActivatedEventArgs = _ns_module.IContactMessageActivatedEventArgs
IContactPanelActivatedEventArgs = _ns_module.IContactPanelActivatedEventArgs
IContactPickerActivatedEventArgs = _ns_module.IContactPickerActivatedEventArgs
IContactPostActivatedEventArgs = _ns_module.IContactPostActivatedEventArgs
IContactVideoCallActivatedEventArgs = _ns_module.IContactVideoCallActivatedEventArgs
IContactsProviderActivatedEventArgs = _ns_module.IContactsProviderActivatedEventArgs
IContinuationActivatedEventArgs = _ns_module.IContinuationActivatedEventArgs
IDeviceActivatedEventArgs = _ns_module.IDeviceActivatedEventArgs
IDevicePairingActivatedEventArgs = _ns_module.IDevicePairingActivatedEventArgs
IDialReceiverActivatedEventArgs = _ns_module.IDialReceiverActivatedEventArgs
IFileActivatedEventArgs = _ns_module.IFileActivatedEventArgs
IFileActivatedEventArgsWithCallerPackageFamilyName = _ns_module.IFileActivatedEventArgsWithCallerPackageFamilyName
IFileActivatedEventArgsWithNeighboringFiles = _ns_module.IFileActivatedEventArgsWithNeighboringFiles
IFileOpenPickerActivatedEventArgs = _ns_module.IFileOpenPickerActivatedEventArgs
IFileOpenPickerActivatedEventArgs2 = _ns_module.IFileOpenPickerActivatedEventArgs2
IFileOpenPickerContinuationEventArgs = _ns_module.IFileOpenPickerContinuationEventArgs
IFileSavePickerActivatedEventArgs = _ns_module.IFileSavePickerActivatedEventArgs
IFileSavePickerActivatedEventArgs2 = _ns_module.IFileSavePickerActivatedEventArgs2
IFileSavePickerContinuationEventArgs = _ns_module.IFileSavePickerContinuationEventArgs
IFolderPickerContinuationEventArgs = _ns_module.IFolderPickerContinuationEventArgs
ILaunchActivatedEventArgs = _ns_module.ILaunchActivatedEventArgs
ILaunchActivatedEventArgs2 = _ns_module.ILaunchActivatedEventArgs2
ILockScreenActivatedEventArgs = _ns_module.ILockScreenActivatedEventArgs
ILockScreenCallActivatedEventArgs = _ns_module.ILockScreenCallActivatedEventArgs
IPhoneCallActivatedEventArgs = _ns_module.IPhoneCallActivatedEventArgs
IPickerReturnedActivatedEventArgs = _ns_module.IPickerReturnedActivatedEventArgs
IPrelaunchActivatedEventArgs = _ns_module.IPrelaunchActivatedEventArgs
IPrint3DWorkflowActivatedEventArgs = _ns_module.IPrint3DWorkflowActivatedEventArgs
IPrintTaskSettingsActivatedEventArgs = _ns_module.IPrintTaskSettingsActivatedEventArgs
IProtocolActivatedEventArgs = _ns_module.IProtocolActivatedEventArgs
IProtocolActivatedEventArgsWithCallerPackageFamilyNameAndData = _ns_module.IProtocolActivatedEventArgsWithCallerPackageFamilyNameAndData
IProtocolForResultsActivatedEventArgs = _ns_module.IProtocolForResultsActivatedEventArgs
IRestrictedLaunchActivatedEventArgs = _ns_module.IRestrictedLaunchActivatedEventArgs
ISearchActivatedEventArgs = _ns_module.ISearchActivatedEventArgs
ISearchActivatedEventArgsWithLinguisticDetails = _ns_module.ISearchActivatedEventArgsWithLinguisticDetails
IShareTargetActivatedEventArgs = _ns_module.IShareTargetActivatedEventArgs
IStartupTaskActivatedEventArgs = _ns_module.IStartupTaskActivatedEventArgs
IToastNotificationActivatedEventArgs = _ns_module.IToastNotificationActivatedEventArgs
IUserDataAccountProviderActivatedEventArgs = _ns_module.IUserDataAccountProviderActivatedEventArgs
IViewSwitcherProvider = _ns_module.IViewSwitcherProvider
IVoiceCommandActivatedEventArgs = _ns_module.IVoiceCommandActivatedEventArgs
IWalletActionActivatedEventArgs = _ns_module.IWalletActionActivatedEventArgs
IWebAccountProviderActivatedEventArgs = _ns_module.IWebAccountProviderActivatedEventArgs
IWebAuthenticationBrokerContinuationEventArgs = _ns_module.IWebAuthenticationBrokerContinuationEventArgs
