// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.ApplicationModel.Activation.h")
#include "py.Windows.ApplicationModel.Activation.h"
#endif

#if __has_include("py.Windows.Devices.Printers.h")
#include "py.Windows.Devices.Printers.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Graphics.Printing.PrintTicket.h")
#include "py.Windows.Graphics.Printing.PrintTicket.h"
#endif

#if __has_include("py.Windows.Storage.h")
#include "py.Windows.Storage.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

#include <winrt/Windows.ApplicationModel.Activation.h>
#include <winrt/Windows.Devices.Printers.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Graphics.Printing.PrintTicket.h>
#include <winrt/Windows.Storage.h>
#include <winrt/Windows.Storage.Streams.h>
#include <winrt/Windows.System.h>

#include <winrt/Windows.Graphics.Printing.Workflow.h>

namespace py::proj::Windows::Graphics::Printing::Workflow
{}

namespace py::impl::Windows::Graphics::Printing::Workflow
{}

namespace py::wrapper::Windows::Graphics::Printing::Workflow
{
    using PrintWorkflowBackgroundSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSession>;
    using PrintWorkflowBackgroundSetupRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSetupRequestedEventArgs>;
    using PrintWorkflowConfiguration = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowConfiguration>;
    using PrintWorkflowForegroundSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSession>;
    using PrintWorkflowForegroundSetupRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSetupRequestedEventArgs>;
    using PrintWorkflowJobActivatedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobActivatedEventArgs>;
    using PrintWorkflowJobBackgroundSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobBackgroundSession>;
    using PrintWorkflowJobNotificationEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobNotificationEventArgs>;
    using PrintWorkflowJobStartingEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobStartingEventArgs>;
    using PrintWorkflowJobTriggerDetails = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobTriggerDetails>;
    using PrintWorkflowJobUISession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobUISession>;
    using PrintWorkflowObjectModelSourceFileContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelSourceFileContent>;
    using PrintWorkflowObjectModelTargetPackage = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelTargetPackage>;
    using PrintWorkflowPdlConverter = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConverter>;
    using PrintWorkflowPdlDataAvailableEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlDataAvailableEventArgs>;
    using PrintWorkflowPdlModificationRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlModificationRequestedEventArgs>;
    using PrintWorkflowPdlSourceContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlSourceContent>;
    using PrintWorkflowPdlTargetStream = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlTargetStream>;
    using PrintWorkflowPrinterJob = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJob>;
    using PrintWorkflowSourceContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSourceContent>;
    using PrintWorkflowSpoolStreamContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSpoolStreamContent>;
    using PrintWorkflowStreamTarget = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowStreamTarget>;
    using PrintWorkflowSubmittedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedEventArgs>;
    using PrintWorkflowSubmittedOperation = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedOperation>;
    using PrintWorkflowTarget = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTarget>;
    using PrintWorkflowTriggerDetails = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTriggerDetails>;
    using PrintWorkflowUIActivatedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUIActivatedEventArgs>;
    using PrintWorkflowUILauncher = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUILauncher>;
    using PrintWorkflowXpsDataAvailableEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowXpsDataAvailableEventArgs>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PdlConversionHostBasedProcessingOperations> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowAttributesMergePolicy> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobAbortReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConversionType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJobStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSessionStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUICompletionStatus> = "i";


    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PdlConversionHostBasedProcessingOperations>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowAttributesMergePolicy>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobAbortReason>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConversionType>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJobStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSessionStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUICompletionStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSession>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSetupRequestedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowConfiguration>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSession>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSetupRequestedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobActivatedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobBackgroundSession>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobNotificationEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobStartingEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobTriggerDetails>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobUISession>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelSourceFileContent>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelTargetPackage>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConverter>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlDataAvailableEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlModificationRequestedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlSourceContent>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlTargetStream>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJob>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSourceContent>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSpoolStreamContent>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowStreamTarget>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedOperation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTarget>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTriggerDetails>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUIActivatedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUILauncher>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowXpsDataAvailableEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
