# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Custom")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class DeviceAccessMode(enum.IntEnum):
    READ = 0
    WRITE = 1
    READ_WRITE = 2

class DeviceSharingMode(enum.IntEnum):
    SHARED = 0
    EXCLUSIVE = 1

class IOControlAccessMode(enum.IntEnum):
    ANY = 0
    READ = 1
    WRITE = 2
    READ_WRITE = 3

class IOControlBufferingMethod(enum.IntEnum):
    BUFFERED = 0
    DIRECT_INPUT = 1
    DIRECT_OUTPUT = 2
    NEITHER = 3

_ns_module._register_DeviceAccessMode(DeviceAccessMode)
_ns_module._register_DeviceSharingMode(DeviceSharingMode)
_ns_module._register_IOControlAccessMode(IOControlAccessMode)
_ns_module._register_IOControlBufferingMethod(IOControlBufferingMethod)

CustomDevice = _ns_module.CustomDevice
IOControlCode = _ns_module.IOControlCode
KnownDeviceTypes = _ns_module.KnownDeviceTypes
IIOControlCode = _ns_module.IIOControlCode
