# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class RemoteTextConnection(winsdk.system.Object):
    is_enabled: winsdk.system.Boolean
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RemoteTextConnection: ...
    def __new__(cls: typing.Type[RemoteTextConnection], connection_id: winsdk.system.Guid, pdu_forwarder: typing.Optional[RemoteTextConnectionDataHandler]) -> RemoteTextConnection:...
    def close(self) -> None: ...
    def register_thread(self, thread_id: winsdk.system.UInt32) -> None: ...
    def report_data_received(self, pdu_data: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def unregister_thread(self, thread_id: winsdk.system.UInt32) -> None: ...

RemoteTextConnectionDataHandler = typing.Callable[[winsdk.system.Array[winsdk.system.UInt8]], winsdk.system.Boolean]

