# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Contacts.DataProvider")

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass


ContactDataProviderConnection = _ns_module.ContactDataProviderConnection
ContactDataProviderTriggerDetails = _ns_module.ContactDataProviderTriggerDetails
ContactListCreateOrUpdateContactRequest = _ns_module.ContactListCreateOrUpdateContactRequest
ContactListCreateOrUpdateContactRequestEventArgs = _ns_module.ContactListCreateOrUpdateContactRequestEventArgs
ContactListDeleteContactRequest = _ns_module.ContactListDeleteContactRequest
ContactListDeleteContactRequestEventArgs = _ns_module.ContactListDeleteContactRequestEventArgs
ContactListServerSearchReadBatchRequest = _ns_module.ContactListServerSearchReadBatchRequest
ContactListServerSearchReadBatchRequestEventArgs = _ns_module.ContactListServerSearchReadBatchRequestEventArgs
ContactListSyncManagerSyncRequest = _ns_module.ContactListSyncManagerSyncRequest
ContactListSyncManagerSyncRequestEventArgs = _ns_module.ContactListSyncManagerSyncRequestEventArgs
