// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Storage.h")
#include "py.Windows.Storage.h"
#endif

#if __has_include("py.Windows.Storage.FileProperties.h")
#include "py.Windows.Storage.FileProperties.h"
#endif

#if __has_include("py.Windows.Storage.Search.h")
#include "py.Windows.Storage.Search.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Storage.h>
#include <winrt/Windows.Storage.FileProperties.h>
#include <winrt/Windows.Storage.Search.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Storage.BulkAccess.h>

namespace py::proj::Windows::Storage::BulkAccess
{}

namespace py::impl::Windows::Storage::BulkAccess
{}

namespace py::wrapper::Windows::Storage::BulkAccess
{
    using FileInformation = py::winrt_wrapper<winrt::Windows::Storage::BulkAccess::FileInformation>;
    using FileInformationFactory = py::winrt_wrapper<winrt::Windows::Storage::BulkAccess::FileInformationFactory>;
    using FolderInformation = py::winrt_wrapper<winrt::Windows::Storage::BulkAccess::FolderInformation>;
    using IStorageItemInformation = py::winrt_wrapper<winrt::Windows::Storage::BulkAccess::IStorageItemInformation>;
}

namespace py
{

    template<>
    struct winrt_type<winrt::Windows::Storage::BulkAccess::FileInformation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Storage::BulkAccess::FileInformationFactory>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Storage::BulkAccess::FolderInformation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Storage::BulkAccess::IStorageItemInformation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
