# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

Self = typing.TypeVar('Self')

class Battery(winsdk.system.Object):
    remaining_charge_percent: winsdk.system.Int32
    remaining_discharge_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Battery: ...
    @staticmethod
    def get_default() -> typing.Optional[Battery]: ...
    def add_remaining_charge_percent_changed(self, change_handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_remaining_charge_percent_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

