# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Haptics")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class VibrationAccessStatus(enum.IntEnum):
    ALLOWED = 0
    DENIED_BY_USER = 1
    DENIED_BY_SYSTEM = 2
    DENIED_BY_ENERGY_SAVER = 3

_ns_module._register_VibrationAccessStatus(VibrationAccessStatus)

KnownSimpleHapticsControllerWaveforms = _ns_module.KnownSimpleHapticsControllerWaveforms
SimpleHapticsController = _ns_module.SimpleHapticsController
SimpleHapticsControllerFeedback = _ns_module.SimpleHapticsControllerFeedback
VibrationDevice = _ns_module.VibrationDevice
