# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input.Core")

try:
    import winsdk.windows.applicationmodel.core
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

try:
    import winsdk.windows.ui.input
except ImportError:
    pass


RadialControllerIndependentInputSource = _ns_module.RadialControllerIndependentInputSource
