# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Email")

try:
    import winsdk.windows.applicationmodel.appointments
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.cryptography.certificates
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class EmailAttachmentDownloadState(enum.IntEnum):
    NOT_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    FAILED = 3

class EmailBatchStatus(enum.IntEnum):
    SUCCESS = 0
    SERVER_SEARCH_SYNC_MANAGER_ERROR = 1
    SERVER_SEARCH_UNKNOWN_ERROR = 2

class EmailCertificateValidationStatus(enum.IntEnum):
    SUCCESS = 0
    NO_MATCH = 1
    INVALID_USAGE = 2
    INVALID_CERTIFICATE = 3
    REVOKED = 4
    CHAIN_REVOKED = 5
    REVOCATION_SERVER_FAILURE = 6
    EXPIRED = 7
    UNTRUSTED = 8
    SERVER_ERROR = 9
    UNKNOWN_FAILURE = 10

class EmailFlagState(enum.IntEnum):
    UNFLAGGED = 0
    FLAGGED = 1
    COMPLETED = 2
    CLEARED = 3

class EmailImportance(enum.IntEnum):
    NORMAL = 0
    HIGH = 1
    LOW = 2

class EmailMailboxActionKind(enum.IntEnum):
    MARK_MESSAGE_AS_SEEN = 0
    MARK_MESSAGE_READ = 1
    CHANGE_MESSAGE_FLAG_STATE = 2
    MOVE_MESSAGE = 3
    SAVE_DRAFT = 4
    SEND_MESSAGE = 5
    CREATE_RESPONSE_REPLY_MESSAGE = 6
    CREATE_RESPONSE_REPLY_ALL_MESSAGE = 7
    CREATE_RESPONSE_FORWARD_MESSAGE = 8
    MOVE_FOLDER = 9
    MARK_FOLDER_FOR_SYNC_ENABLED = 10

class EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation(enum.IntEnum):
    NONE = 0
    STRONG_ALGORITHM = 1
    ANY_ALGORITHM = 2

class EmailMailboxAutoReplyMessageResponseKind(enum.IntEnum):
    HTML = 0
    PLAIN_TEXT = 1

class EmailMailboxChangeType(enum.IntEnum):
    MESSAGE_CREATED = 0
    MESSAGE_MODIFIED = 1
    MESSAGE_DELETED = 2
    FOLDER_CREATED = 3
    FOLDER_MODIFIED = 4
    FOLDER_DELETED = 5
    CHANGE_TRACKING_LOST = 6

class EmailMailboxCreateFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    NAME_COLLISION = 5
    SERVER_REJECTED = 6

class EmailMailboxDeleteFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    COULD_NOT_DELETE_EVERYTHING = 5

class EmailMailboxEmptyFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    COULD_NOT_DELETE_EVERYTHING = 5

class EmailMailboxOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    FULL = 1
    NONE = 2

class EmailMailboxOtherAppWriteAccess(enum.IntEnum):
    NONE = 0
    LIMITED = 1

class EmailMailboxSmimeEncryptionAlgorithm(enum.IntEnum):
    ANY = 0
    TRIPLE_DES = 1
    DES = 2
    R_C2128_BIT = 3
    R_C264_BIT = 4
    R_C240_BIT = 5

class EmailMailboxSmimeSigningAlgorithm(enum.IntEnum):
    ANY = 0
    SHA1 = 1
    M_D5 = 2

class EmailMailboxSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5
    MANUAL_ACCOUNT_REMOVAL_REQUIRED = 6

class EmailMeetingResponseType(enum.IntEnum):
    ACCEPT = 0
    DECLINE = 1
    TENTATIVE = 2

class EmailMessageBodyKind(enum.IntEnum):
    HTML = 0
    PLAIN_TEXT = 1

class EmailMessageDownloadState(enum.IntEnum):
    PARTIALLY_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    FAILED = 3

class EmailMessageResponseKind(enum.IntEnum):
    NONE = 0
    REPLY = 1
    REPLY_ALL = 2
    FORWARD = 3

class EmailMessageSmimeKind(enum.IntEnum):
    NONE = 0
    CLEAR_SIGNED = 1
    OPAQUE_SIGNED = 2
    ENCRYPTED = 3

class EmailQueryKind(enum.IntEnum):
    ALL = 0
    IMPORTANT = 1
    FLAGGED = 2
    UNREAD = 3
    READ = 4
    UNSEEN = 5

class EmailQuerySearchFields(enum.IntFlag):
    NONE = 0
    SUBJECT = 0x1
    SENDER = 0x2
    PREVIEW = 0x4
    RECIPIENTS = 0x8
    ALL = 0xffffffff

class EmailQuerySearchScope(enum.IntEnum):
    LOCAL = 0
    SERVER = 1

class EmailQuerySortDirection(enum.IntEnum):
    DESCENDING = 0
    ASCENDING = 1

class EmailQuerySortProperty(enum.IntEnum):
    DATE = 0

class EmailRecipientResolutionStatus(enum.IntEnum):
    SUCCESS = 0
    RECIPIENT_NOT_FOUND = 1
    AMBIGUOUS_RECIPIENT = 2
    NO_CERTIFICATE = 3
    CERTIFICATE_REQUEST_LIMIT_REACHED = 4
    CANNOT_RESOLVE_DISTRIBUTION_LIST = 5
    SERVER_ERROR = 6
    UNKNOWN_FAILURE = 7

class EmailSpecialFolderKind(enum.IntEnum):
    NONE = 0
    ROOT = 1
    INBOX = 2
    OUTBOX = 3
    DRAFTS = 4
    DELETED_ITEMS = 5
    SENT = 6

class EmailStoreAccessType(enum.IntEnum):
    APP_MAILBOXES_READ_WRITE = 0
    ALL_MAILBOXES_LIMITED_READ_WRITE = 1

_ns_module._register_EmailAttachmentDownloadState(EmailAttachmentDownloadState)
_ns_module._register_EmailBatchStatus(EmailBatchStatus)
_ns_module._register_EmailCertificateValidationStatus(EmailCertificateValidationStatus)
_ns_module._register_EmailFlagState(EmailFlagState)
_ns_module._register_EmailImportance(EmailImportance)
_ns_module._register_EmailMailboxActionKind(EmailMailboxActionKind)
_ns_module._register_EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation(EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation)
_ns_module._register_EmailMailboxAutoReplyMessageResponseKind(EmailMailboxAutoReplyMessageResponseKind)
_ns_module._register_EmailMailboxChangeType(EmailMailboxChangeType)
_ns_module._register_EmailMailboxCreateFolderStatus(EmailMailboxCreateFolderStatus)
_ns_module._register_EmailMailboxDeleteFolderStatus(EmailMailboxDeleteFolderStatus)
_ns_module._register_EmailMailboxEmptyFolderStatus(EmailMailboxEmptyFolderStatus)
_ns_module._register_EmailMailboxOtherAppReadAccess(EmailMailboxOtherAppReadAccess)
_ns_module._register_EmailMailboxOtherAppWriteAccess(EmailMailboxOtherAppWriteAccess)
_ns_module._register_EmailMailboxSmimeEncryptionAlgorithm(EmailMailboxSmimeEncryptionAlgorithm)
_ns_module._register_EmailMailboxSmimeSigningAlgorithm(EmailMailboxSmimeSigningAlgorithm)
_ns_module._register_EmailMailboxSyncStatus(EmailMailboxSyncStatus)
_ns_module._register_EmailMeetingResponseType(EmailMeetingResponseType)
_ns_module._register_EmailMessageBodyKind(EmailMessageBodyKind)
_ns_module._register_EmailMessageDownloadState(EmailMessageDownloadState)
_ns_module._register_EmailMessageResponseKind(EmailMessageResponseKind)
_ns_module._register_EmailMessageSmimeKind(EmailMessageSmimeKind)
_ns_module._register_EmailQueryKind(EmailQueryKind)
_ns_module._register_EmailQuerySearchFields(EmailQuerySearchFields)
_ns_module._register_EmailQuerySearchScope(EmailQuerySearchScope)
_ns_module._register_EmailQuerySortDirection(EmailQuerySortDirection)
_ns_module._register_EmailQuerySortProperty(EmailQuerySortProperty)
_ns_module._register_EmailRecipientResolutionStatus(EmailRecipientResolutionStatus)
_ns_module._register_EmailSpecialFolderKind(EmailSpecialFolderKind)
_ns_module._register_EmailStoreAccessType(EmailStoreAccessType)

EmailAttachment = _ns_module.EmailAttachment
EmailConversation = _ns_module.EmailConversation
EmailConversationBatch = _ns_module.EmailConversationBatch
EmailConversationReader = _ns_module.EmailConversationReader
EmailFolder = _ns_module.EmailFolder
EmailIrmInfo = _ns_module.EmailIrmInfo
EmailIrmTemplate = _ns_module.EmailIrmTemplate
EmailItemCounts = _ns_module.EmailItemCounts
EmailMailbox = _ns_module.EmailMailbox
EmailMailboxAction = _ns_module.EmailMailboxAction
EmailMailboxAutoReply = _ns_module.EmailMailboxAutoReply
EmailMailboxAutoReplySettings = _ns_module.EmailMailboxAutoReplySettings
EmailMailboxCapabilities = _ns_module.EmailMailboxCapabilities
EmailMailboxChange = _ns_module.EmailMailboxChange
EmailMailboxChangeReader = _ns_module.EmailMailboxChangeReader
EmailMailboxChangeTracker = _ns_module.EmailMailboxChangeTracker
EmailMailboxChangedDeferral = _ns_module.EmailMailboxChangedDeferral
EmailMailboxChangedEventArgs = _ns_module.EmailMailboxChangedEventArgs
EmailMailboxCreateFolderResult = _ns_module.EmailMailboxCreateFolderResult
EmailMailboxPolicies = _ns_module.EmailMailboxPolicies
EmailMailboxSyncManager = _ns_module.EmailMailboxSyncManager
EmailManager = _ns_module.EmailManager
EmailManagerForUser = _ns_module.EmailManagerForUser
EmailMeetingInfo = _ns_module.EmailMeetingInfo
EmailMessage = _ns_module.EmailMessage
EmailMessageBatch = _ns_module.EmailMessageBatch
EmailMessageReader = _ns_module.EmailMessageReader
EmailQueryOptions = _ns_module.EmailQueryOptions
EmailQueryTextSearch = _ns_module.EmailQueryTextSearch
EmailRecipient = _ns_module.EmailRecipient
EmailRecipientResolutionResult = _ns_module.EmailRecipientResolutionResult
EmailStore = _ns_module.EmailStore
EmailStoreNotificationTriggerDetails = _ns_module.EmailStoreNotificationTriggerDetails
