// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Data_Pdf_1_H
#define WINRT_Windows_Data_Pdf_1_H
#include "winrt/impl/Windows.Data.Pdf.0.h"
WINRT_EXPORT namespace winrt::Windows::Data::Pdf
{
    struct WINRT_IMPL_EMPTY_BASES IPdfDocument :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPdfDocument>
    {
        IPdfDocument(std::nullptr_t = nullptr) noexcept {}
        IPdfDocument(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPdfDocumentStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPdfDocumentStatics>
    {
        IPdfDocumentStatics(std::nullptr_t = nullptr) noexcept {}
        IPdfDocumentStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPdfPage :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPdfPage>
    {
        IPdfPage(std::nullptr_t = nullptr) noexcept {}
        IPdfPage(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPdfPageDimensions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPdfPageDimensions>
    {
        IPdfPageDimensions(std::nullptr_t = nullptr) noexcept {}
        IPdfPageDimensions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPdfPageRenderOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPdfPageRenderOptions>
    {
        IPdfPageRenderOptions(std::nullptr_t = nullptr) noexcept {}
        IPdfPageRenderOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
