# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Core")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.activation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

class AppRestartFailureReason(enum.IntEnum):
    RESTART_PENDING = 0
    NOT_IN_FOREGROUND = 1
    INVALID_USER = 2
    OTHER = 3

_ns_module._register_AppRestartFailureReason(AppRestartFailureReason)

AppListEntry = _ns_module.AppListEntry
CoreApplication = _ns_module.CoreApplication
CoreApplicationView = _ns_module.CoreApplicationView
CoreApplicationViewTitleBar = _ns_module.CoreApplicationViewTitleBar
HostedViewClosingEventArgs = _ns_module.HostedViewClosingEventArgs
UnhandledError = _ns_module.UnhandledError
UnhandledErrorDetectedEventArgs = _ns_module.UnhandledErrorDetectedEventArgs
ICoreApplicationUnhandledError = _ns_module.ICoreApplicationUnhandledError
IFrameworkView = _ns_module.IFrameworkView
IFrameworkViewSource = _ns_module.IFrameworkViewSource
