# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Management")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class MdmAlertDataType(enum.IntEnum):
    STRING = 0
    BASE64 = 1
    BOOLEAN = 2
    INTEGER = 3

class MdmAlertMark(enum.IntEnum):
    NONE = 0
    FATAL = 1
    CRITICAL = 2
    WARNING = 3
    INFORMATIONAL = 4

class MdmSessionState(enum.IntEnum):
    NOT_STARTED = 0
    STARTING = 1
    CONNECTING = 2
    COMMUNICATING = 3
    ALERT_STATUS_AVAILABLE = 4
    RETRYING = 5
    COMPLETED = 6

_ns_module._register_MdmAlertDataType(MdmAlertDataType)
_ns_module._register_MdmAlertMark(MdmAlertMark)
_ns_module._register_MdmSessionState(MdmSessionState)

MdmAlert = _ns_module.MdmAlert
MdmSession = _ns_module.MdmSession
MdmSessionManager = _ns_module.MdmSessionManager
