// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#include <winrt/Windows.Foundation.Collections.h>

#include <winrt/Windows.Devices.Adc.Provider.h>

namespace py::proj::Windows::Devices::Adc::Provider
{}

namespace py::impl::Windows::Devices::Adc::Provider
{}

namespace py::wrapper::Windows::Devices::Adc::Provider
{
    using IAdcControllerProvider = py::winrt_wrapper<winrt::Windows::Devices::Adc::Provider::IAdcControllerProvider>;
    using IAdcProvider = py::winrt_wrapper<winrt::Windows::Devices::Adc::Provider::IAdcProvider>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::Adc::Provider::ProviderAdcChannelMode> = "i";


    template<>
    struct py_type<winrt::Windows::Devices::Adc::Provider::ProviderAdcChannelMode>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Adc::Provider::IAdcControllerProvider>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Adc::Provider::IAdcProvider>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
