# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class MdmAlertDataType(enum.IntEnum):
    STRING = 0
    BASE64 = 1
    BOOLEAN = 2
    INTEGER = 3

class MdmAlertMark(enum.IntEnum):
    NONE = 0
    FATAL = 1
    CRITICAL = 2
    WARNING = 3
    INFORMATIONAL = 4

class MdmSessionState(enum.IntEnum):
    NOT_STARTED = 0
    STARTING = 1
    CONNECTING = 2
    COMMUNICATING = 3
    ALERT_STATUS_AVAILABLE = 4
    RETRYING = 5
    COMPLETED = 6

Self = typing.TypeVar('Self')

class MdmAlert(winsdk.system.Object):
    type: str
    target: str
    source: str
    mark: MdmAlertMark
    format: MdmAlertDataType
    data: str
    status: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MdmAlert: ...
    def __new__(cls: typing.Type[MdmAlert]) -> MdmAlert:...

class MdmSession(winsdk.system.Object):
    alerts: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MdmAlert]]
    extended_error: winsdk.windows.foundation.HResult
    id: str
    state: MdmSessionState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MdmSession: ...
    def attach_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete(self) -> None: ...
    @typing.overload
    def start_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_async(self, alerts: typing.Iterable[MdmAlert]) -> winsdk.windows.foundation.IAsyncAction: ...

class MdmSessionManager(winsdk.system.Object):
    session_ids: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MdmSessionManager: ...
    @staticmethod
    def delete_session_by_id(session_id: str) -> None: ...
    @staticmethod
    def get_session_by_id(session_id: str) -> typing.Optional[MdmSession]: ...
    @staticmethod
    def try_create_session() -> typing.Optional[MdmSession]: ...

