# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Globalization.NumberFormatting")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class CurrencyFormatterMode(enum.IntEnum):
    USE_SYMBOL = 0
    USE_CURRENCY_CODE = 1

class RoundingAlgorithm(enum.IntEnum):
    NONE = 0
    ROUND_DOWN = 1
    ROUND_UP = 2
    ROUND_TOWARDS_ZERO = 3
    ROUND_AWAY_FROM_ZERO = 4
    ROUND_HALF_DOWN = 5
    ROUND_HALF_UP = 6
    ROUND_HALF_TOWARDS_ZERO = 7
    ROUND_HALF_AWAY_FROM_ZERO = 8
    ROUND_HALF_TO_EVEN = 9
    ROUND_HALF_TO_ODD = 10

_ns_module._register_CurrencyFormatterMode(CurrencyFormatterMode)
_ns_module._register_RoundingAlgorithm(RoundingAlgorithm)

CurrencyFormatter = _ns_module.CurrencyFormatter
DecimalFormatter = _ns_module.DecimalFormatter
IncrementNumberRounder = _ns_module.IncrementNumberRounder
NumeralSystemTranslator = _ns_module.NumeralSystemTranslator
PercentFormatter = _ns_module.PercentFormatter
PermilleFormatter = _ns_module.PermilleFormatter
SignificantDigitsNumberRounder = _ns_module.SignificantDigitsNumberRounder
INumberFormatter = _ns_module.INumberFormatter
INumberFormatter2 = _ns_module.INumberFormatter2
INumberFormatterOptions = _ns_module.INumberFormatterOptions
INumberParser = _ns_module.INumberParser
INumberRounder = _ns_module.INumberRounder
INumberRounderOption = _ns_module.INumberRounderOption
ISignedZeroOption = _ns_module.ISignedZeroOption
ISignificantDigitsOption = _ns_module.ISignificantDigitsOption
