# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.PersonalInformation")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class ContactChangeType(enum.IntEnum):
    CREATED = 0
    MODIFIED = 1
    DELETED = 2

class ContactQueryResultOrdering(enum.IntEnum):
    SYSTEM_DEFAULT = 0
    GIVEN_NAME_FAMILY_NAME = 1
    FAMILY_NAME_GIVEN_NAME = 2

class ContactStoreApplicationAccessMode(enum.IntEnum):
    LIMITED_READ_ONLY = 0
    READ_ONLY = 1

class ContactStoreSystemAccessMode(enum.IntEnum):
    READ_ONLY = 0
    READ_WRITE = 1

class VCardFormat(enum.IntEnum):
    VERSION2_1 = 0
    VERSION3 = 1

_ns_module._register_ContactChangeType(ContactChangeType)
_ns_module._register_ContactQueryResultOrdering(ContactQueryResultOrdering)
_ns_module._register_ContactStoreApplicationAccessMode(ContactStoreApplicationAccessMode)
_ns_module._register_ContactStoreSystemAccessMode(ContactStoreSystemAccessMode)
_ns_module._register_VCardFormat(VCardFormat)

ContactAddress = _ns_module.ContactAddress
ContactChangeRecord = _ns_module.ContactChangeRecord
ContactInformation = _ns_module.ContactInformation
ContactQueryOptions = _ns_module.ContactQueryOptions
ContactQueryResult = _ns_module.ContactQueryResult
ContactStore = _ns_module.ContactStore
KnownContactProperties = _ns_module.KnownContactProperties
StoredContact = _ns_module.StoredContact
IContactInformation = _ns_module.IContactInformation
IContactInformation2 = _ns_module.IContactInformation2
