// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.System.Diagnostics.h")
#include "py.Windows.System.Diagnostics.h"
#endif

#if __has_include("py.Windows.Web.Http.h")
#include "py.Windows.Web.Http.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.System.Diagnostics.h>
#include <winrt/Windows.Web.Http.h>

#include <winrt/Windows.Web.Http.Diagnostics.h>

namespace py::proj::Windows::Web::Http::Diagnostics
{}

namespace py::impl::Windows::Web::Http::Diagnostics
{}

namespace py::wrapper::Windows::Web::Http::Diagnostics
{
    using HttpDiagnosticProvider = py::winrt_wrapper<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProvider>;
    using HttpDiagnosticProviderRequestResponseCompletedEventArgs = py::winrt_wrapper<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderRequestResponseCompletedEventArgs>;
    using HttpDiagnosticProviderRequestResponseTimestamps = py::winrt_wrapper<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderRequestResponseTimestamps>;
    using HttpDiagnosticProviderRequestSentEventArgs = py::winrt_wrapper<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderRequestSentEventArgs>;
    using HttpDiagnosticProviderResponseReceivedEventArgs = py::winrt_wrapper<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderResponseReceivedEventArgs>;
    using HttpDiagnosticSourceLocation = py::winrt_wrapper<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticSourceLocation>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticRequestInitiator> = "i";


    template<>
    struct py_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticRequestInitiator>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProvider>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderRequestResponseCompletedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderRequestResponseTimestamps>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderRequestSentEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticProviderResponseReceivedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Web::Http::Diagnostics::HttpDiagnosticSourceLocation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
