# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Foundation.Numerics")


Matrix3x2 = _ns_module.Matrix3x2
Matrix4x4 = _ns_module.Matrix4x4
Plane = _ns_module.Plane
Quaternion = _ns_module.Quaternion
Rational = _ns_module.Rational
Vector2 = _ns_module.Vector2
Vector3 = _ns_module.Vector3
Vector4 = _ns_module.Vector4
