// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Globalization.h")
#include "py.Windows.Globalization.h"
#endif

#if __has_include("py.Windows.UI.Text.h")
#include "py.Windows.UI.Text.h"
#endif

#if __has_include("py.Windows.UI.ViewManagement.h")
#include "py.Windows.UI.ViewManagement.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Globalization.h>
#include <winrt/Windows.UI.Text.h>
#include <winrt/Windows.UI.ViewManagement.h>

#include <winrt/Windows.UI.Text.Core.h>

namespace py::proj::Windows::UI::Text::Core
{}

namespace py::impl::Windows::UI::Text::Core
{}

namespace py::wrapper::Windows::UI::Text::Core
{
    using CoreTextCompositionCompletedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextCompositionCompletedEventArgs>;
    using CoreTextCompositionSegment = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextCompositionSegment>;
    using CoreTextCompositionStartedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextCompositionStartedEventArgs>;
    using CoreTextEditContext = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextEditContext>;
    using CoreTextFormatUpdatingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextFormatUpdatingEventArgs>;
    using CoreTextLayoutBounds = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextLayoutBounds>;
    using CoreTextLayoutRequest = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextLayoutRequest>;
    using CoreTextLayoutRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextLayoutRequestedEventArgs>;
    using CoreTextSelectionRequest = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextSelectionRequest>;
    using CoreTextSelectionRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextSelectionRequestedEventArgs>;
    using CoreTextSelectionUpdatingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextSelectionUpdatingEventArgs>;
    using CoreTextServicesConstants = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextServicesConstants>;
    using CoreTextServicesManager = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextServicesManager>;
    using CoreTextTextRequest = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextTextRequest>;
    using CoreTextTextRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextTextRequestedEventArgs>;
    using CoreTextTextUpdatingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Text::Core::CoreTextTextUpdatingEventArgs>;
    using CoreTextRange = py::winrt_struct_wrapper<winrt::Windows::UI::Text::Core::CoreTextRange>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextFormatUpdatingReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextFormatUpdatingResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextInputPaneDisplayPolicy> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextInputScope> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextSelectionUpdatingResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextTextUpdatingResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Text::Core::CoreTextRange> = "T{i:start_caret_position:i:end_caret_position:}";


    template<>
    struct py_type<winrt::Windows::UI::Text::Core::CoreTextFormatUpdatingReason>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Text::Core::CoreTextFormatUpdatingResult>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Text::Core::CoreTextInputPaneDisplayPolicy>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Text::Core::CoreTextInputScope>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Text::Core::CoreTextSelectionUpdatingResult>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Text::Core::CoreTextTextUpdatingResult>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextCompositionCompletedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextCompositionSegment>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextCompositionStartedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextEditContext>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextFormatUpdatingEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextLayoutBounds>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextLayoutRequest>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextLayoutRequestedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextSelectionRequest>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextSelectionRequestedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextSelectionUpdatingEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextServicesConstants>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextServicesManager>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextTextRequest>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextTextRequestedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextTextUpdatingEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Text::Core::CoreTextRange>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
    template<>
    struct converter<winrt::Windows::UI::Text::Core::CoreTextRange>
    {
        static PyObject* convert(winrt::Windows::UI::Text::Core::CoreTextRange instance) noexcept;
        static winrt::Windows::UI::Text::Core::CoreTextRange convert_to(PyObject* obj);
    };

}
