// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Media_DialProtocol_1_H
#define WINRT_Windows_Media_DialProtocol_1_H
#include "winrt/impl/Windows.Media.DialProtocol.0.h"
WINRT_EXPORT namespace winrt::Windows::Media::DialProtocol
{
    struct WINRT_IMPL_EMPTY_BASES IDialApp :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialApp>
    {
        IDialApp(std::nullptr_t = nullptr) noexcept {}
        IDialApp(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialAppStateDetails :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialAppStateDetails>
    {
        IDialAppStateDetails(std::nullptr_t = nullptr) noexcept {}
        IDialAppStateDetails(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDevice :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDevice>
    {
        IDialDevice(std::nullptr_t = nullptr) noexcept {}
        IDialDevice(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDevice2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDevice2>
    {
        IDialDevice2(std::nullptr_t = nullptr) noexcept {}
        IDialDevice2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDevicePicker :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDevicePicker>
    {
        IDialDevicePicker(std::nullptr_t = nullptr) noexcept {}
        IDialDevicePicker(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDevicePickerFilter :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDevicePickerFilter>
    {
        IDialDevicePickerFilter(std::nullptr_t = nullptr) noexcept {}
        IDialDevicePickerFilter(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDeviceSelectedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDeviceSelectedEventArgs>
    {
        IDialDeviceSelectedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IDialDeviceSelectedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDeviceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDeviceStatics>
    {
        IDialDeviceStatics(std::nullptr_t = nullptr) noexcept {}
        IDialDeviceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialDisconnectButtonClickedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialDisconnectButtonClickedEventArgs>
    {
        IDialDisconnectButtonClickedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IDialDisconnectButtonClickedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialReceiverApp :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialReceiverApp>
    {
        IDialReceiverApp(std::nullptr_t = nullptr) noexcept {}
        IDialReceiverApp(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialReceiverApp2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialReceiverApp2>
    {
        IDialReceiverApp2(std::nullptr_t = nullptr) noexcept {}
        IDialReceiverApp2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDialReceiverAppStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDialReceiverAppStatics>
    {
        IDialReceiverAppStatics(std::nullptr_t = nullptr) noexcept {}
        IDialReceiverAppStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
