# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.AppRecording")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class AppRecordingSaveScreenshotOption(enum.IntEnum):
    NONE = 0
    HDR_CONTENT_VISIBLE = 1

_ns_module._register_AppRecordingSaveScreenshotOption(AppRecordingSaveScreenshotOption)

AppRecordingManager = _ns_module.AppRecordingManager
AppRecordingResult = _ns_module.AppRecordingResult
AppRecordingSaveScreenshotResult = _ns_module.AppRecordingSaveScreenshotResult
AppRecordingSavedScreenshotInfo = _ns_module.AppRecordingSavedScreenshotInfo
AppRecordingStatus = _ns_module.AppRecordingStatus
AppRecordingStatusDetails = _ns_module.AppRecordingStatusDetails
