# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class Print3DWorkflowDetail(enum.IntEnum):
    UNKNOWN = 0
    MODEL_EXCEEDS_PRINT_BED = 1
    UPLOAD_FAILED = 2
    INVALID_MATERIAL_SELECTION = 3
    INVALID_MODEL = 4
    MODEL_NOT_MANIFOLD = 5
    INVALID_PRINT_TICKET = 6

class Print3DWorkflowStatus(enum.IntEnum):
    ABANDONED = 0
    CANCELED = 1
    FAILED = 2
    SLICING = 3
    SUBMITTED = 4

Self = typing.TypeVar('Self')

class Print3DWorkflow(winsdk.system.Object):
    is_print_ready: winsdk.system.Boolean
    device_i_d: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DWorkflow: ...
    def get_print_model_package(self) -> typing.Optional[winsdk.system.Object]: ...
    def add_print_requested(self, event_handler: winsdk.windows.foundation.TypedEventHandler[Print3DWorkflow, Print3DWorkflowPrintRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_print_requested(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_printer_changed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[Print3DWorkflow, Print3DWorkflowPrinterChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_printer_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class Print3DWorkflowPrintRequestedEventArgs(winsdk.system.Object):
    status: Print3DWorkflowStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DWorkflowPrintRequestedEventArgs: ...
    def set_extended_status(self, value: Print3DWorkflowDetail) -> None: ...
    def set_source(self, source: typing.Optional[winsdk.system.Object]) -> None: ...
    def set_source_changed(self, value: winsdk.system.Boolean) -> None: ...

class Print3DWorkflowPrinterChangedEventArgs(winsdk.system.Object):
    new_device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DWorkflowPrinterChangedEventArgs: ...

class PrintExtensionContext(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintExtensionContext: ...
    @staticmethod
    def from_device_id(device_id: str) -> typing.Optional[winsdk.system.Object]: ...

class PrintNotificationEventDetails(winsdk.system.Object):
    event_data: str
    printer_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintNotificationEventDetails: ...

class PrintTaskConfiguration(winsdk.system.Object):
    printer_extension_context: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfiguration: ...
    def add_save_requested(self, event_handler: winsdk.windows.foundation.TypedEventHandler[PrintTaskConfiguration, PrintTaskConfigurationSaveRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_save_requested(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PrintTaskConfigurationSaveRequest(winsdk.system.Object):
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfigurationSaveRequest: ...
    def cancel(self) -> None: ...
    def get_deferral(self) -> typing.Optional[PrintTaskConfigurationSaveRequestedDeferral]: ...
    def save(self, printer_extension_context: typing.Optional[winsdk.system.Object]) -> None: ...

class PrintTaskConfigurationSaveRequestedDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfigurationSaveRequestedDeferral: ...
    def complete(self) -> None: ...

class PrintTaskConfigurationSaveRequestedEventArgs(winsdk.system.Object):
    request: typing.Optional[PrintTaskConfigurationSaveRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfigurationSaveRequestedEventArgs: ...

