// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Devices.SerialCommunication.h>

namespace py::proj::Windows::Devices::SerialCommunication
{}

namespace py::impl::Windows::Devices::SerialCommunication
{}

namespace py::wrapper::Windows::Devices::SerialCommunication
{
    using ErrorReceivedEventArgs = py::winrt_wrapper<winrt::Windows::Devices::SerialCommunication::ErrorReceivedEventArgs>;
    using PinChangedEventArgs = py::winrt_wrapper<winrt::Windows::Devices::SerialCommunication::PinChangedEventArgs>;
    using SerialDevice = py::winrt_wrapper<winrt::Windows::Devices::SerialCommunication::SerialDevice>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::SerialCommunication::SerialError> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::SerialCommunication::SerialHandshake> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::SerialCommunication::SerialParity> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::SerialCommunication::SerialPinChange> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::SerialCommunication::SerialStopBitCount> = "i";


    template<>
    struct py_type<winrt::Windows::Devices::SerialCommunication::SerialError>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Devices::SerialCommunication::SerialHandshake>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Devices::SerialCommunication::SerialParity>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Devices::SerialCommunication::SerialPinChange>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Devices::SerialCommunication::SerialStopBitCount>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::SerialCommunication::ErrorReceivedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::SerialCommunication::PinChangedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::SerialCommunication::SerialDevice>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
