# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class PowerSavingMode(enum.IntEnum):
    OFF = 0
    ON = 1

Self = typing.TypeVar('Self')

class PowerManager(winsdk.system.Object):
    power_saving_mode: typing.ClassVar[PowerSavingMode]
    power_saving_mode_enabled: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PowerManager: ...
    @staticmethod
    def add_power_saving_mode_changed(change_handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_power_saving_mode_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

