# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.PersonalInformation.Provisioning")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.phone.personalinformation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


ContactPartnerProvisioningManager = _ns_module.ContactPartnerProvisioningManager
MessagePartnerProvisioningManager = _ns_module.MessagePartnerProvisioningManager
