# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Perception.Spatial")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.perception
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system.remotesystems
except ImportError:
    pass

class SpatialAnchorExportPurpose(enum.IntEnum):
    RELOCALIZATION = 0
    SHARING = 1

class SpatialEntityWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class SpatialLocatability(enum.IntEnum):
    UNAVAILABLE = 0
    ORIENTATION_ONLY = 1
    POSITIONAL_TRACKING_ACTIVATING = 2
    POSITIONAL_TRACKING_ACTIVE = 3
    POSITIONAL_TRACKING_INHIBITED = 4

class SpatialLookDirectionRange(enum.IntEnum):
    FORWARD_ONLY = 0
    OMNIDIRECTIONAL = 1

class SpatialMovementRange(enum.IntEnum):
    NO_MOVEMENT = 0
    BOUNDED = 1

class SpatialPerceptionAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

_ns_module._register_SpatialAnchorExportPurpose(SpatialAnchorExportPurpose)
_ns_module._register_SpatialEntityWatcherStatus(SpatialEntityWatcherStatus)
_ns_module._register_SpatialLocatability(SpatialLocatability)
_ns_module._register_SpatialLookDirectionRange(SpatialLookDirectionRange)
_ns_module._register_SpatialMovementRange(SpatialMovementRange)
_ns_module._register_SpatialPerceptionAccessStatus(SpatialPerceptionAccessStatus)

SpatialBoundingBox = _ns_module.SpatialBoundingBox
SpatialBoundingFrustum = _ns_module.SpatialBoundingFrustum
SpatialBoundingOrientedBox = _ns_module.SpatialBoundingOrientedBox
SpatialBoundingSphere = _ns_module.SpatialBoundingSphere
SpatialRay = _ns_module.SpatialRay
SpatialAnchor = _ns_module.SpatialAnchor
SpatialAnchorExportSufficiency = _ns_module.SpatialAnchorExportSufficiency
SpatialAnchorExporter = _ns_module.SpatialAnchorExporter
SpatialAnchorManager = _ns_module.SpatialAnchorManager
SpatialAnchorRawCoordinateSystemAdjustedEventArgs = _ns_module.SpatialAnchorRawCoordinateSystemAdjustedEventArgs
SpatialAnchorStore = _ns_module.SpatialAnchorStore
SpatialAnchorTransferManager = _ns_module.SpatialAnchorTransferManager
SpatialBoundingVolume = _ns_module.SpatialBoundingVolume
SpatialCoordinateSystem = _ns_module.SpatialCoordinateSystem
SpatialEntity = _ns_module.SpatialEntity
SpatialEntityAddedEventArgs = _ns_module.SpatialEntityAddedEventArgs
SpatialEntityRemovedEventArgs = _ns_module.SpatialEntityRemovedEventArgs
SpatialEntityStore = _ns_module.SpatialEntityStore
SpatialEntityUpdatedEventArgs = _ns_module.SpatialEntityUpdatedEventArgs
SpatialEntityWatcher = _ns_module.SpatialEntityWatcher
SpatialLocation = _ns_module.SpatialLocation
SpatialLocator = _ns_module.SpatialLocator
SpatialLocatorAttachedFrameOfReference = _ns_module.SpatialLocatorAttachedFrameOfReference
SpatialLocatorPositionalTrackingDeactivatingEventArgs = _ns_module.SpatialLocatorPositionalTrackingDeactivatingEventArgs
SpatialStageFrameOfReference = _ns_module.SpatialStageFrameOfReference
SpatialStationaryFrameOfReference = _ns_module.SpatialStationaryFrameOfReference
