// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Phone_UI_Input_1_H
#define WINRT_Windows_Phone_UI_Input_1_H
#include "winrt/impl/Windows.Phone.UI.Input.0.h"
WINRT_EXPORT namespace winrt::Windows::Phone::UI::Input
{
    struct WINRT_IMPL_EMPTY_BASES IBackPressedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBackPressedEventArgs>
    {
        IBackPressedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IBackPressedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICameraEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICameraEventArgs>
    {
        ICameraEventArgs(std::nullptr_t = nullptr) noexcept {}
        ICameraEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IHardwareButtonsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IHardwareButtonsStatics>
    {
        IHardwareButtonsStatics(std::nullptr_t = nullptr) noexcept {}
        IHardwareButtonsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IHardwareButtonsStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IHardwareButtonsStatics2>
    {
        IHardwareButtonsStatics2(std::nullptr_t = nullptr) noexcept {}
        IHardwareButtonsStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
