// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Foundation.Numerics.h")
#include "py.Windows.Foundation.Numerics.h"
#endif

#if __has_include("py.Windows.UI.Composition.h")
#include "py.Windows.UI.Composition.h"
#endif

#if __has_include("py.Windows.UI.Core.h")
#include "py.Windows.UI.Core.h"
#endif

#if __has_include("py.Windows.UI.Input.Inking.h")
#include "py.Windows.UI.Input.Inking.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Foundation.Numerics.h>
#include <winrt/Windows.UI.Composition.h>
#include <winrt/Windows.UI.Core.h>
#include <winrt/Windows.UI.Input.Inking.h>

#include <winrt/Windows.UI.Input.Inking.Core.h>

namespace py::proj::Windows::UI::Input::Inking::Core
{}

namespace py::impl::Windows::UI::Input::Inking::Core
{}

namespace py::wrapper::Windows::UI::Input::Inking::Core
{
    using CoreIncrementalInkStroke = py::winrt_wrapper<winrt::Windows::UI::Input::Inking::Core::CoreIncrementalInkStroke>;
    using CoreInkIndependentInputSource = py::winrt_wrapper<winrt::Windows::UI::Input::Inking::Core::CoreInkIndependentInputSource>;
    using CoreInkPresenterHost = py::winrt_wrapper<winrt::Windows::UI::Input::Inking::Core::CoreInkPresenterHost>;
    using CoreWetStrokeUpdateEventArgs = py::winrt_wrapper<winrt::Windows::UI::Input::Inking::Core::CoreWetStrokeUpdateEventArgs>;
    using CoreWetStrokeUpdateSource = py::winrt_wrapper<winrt::Windows::UI::Input::Inking::Core::CoreWetStrokeUpdateSource>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Input::Inking::Core::CoreWetStrokeDisposition> = "i";


    template<>
    struct py_type<winrt::Windows::UI::Input::Inking::Core::CoreWetStrokeDisposition>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Input::Inking::Core::CoreIncrementalInkStroke>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Input::Inking::Core::CoreInkIndependentInputSource>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Input::Inking::Core::CoreInkPresenterHost>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Input::Inking::Core::CoreWetStrokeUpdateEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Input::Inking::Core::CoreWetStrokeUpdateSource>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
