// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_UI_Xaml_Automation_Text_1_H
#define WINRT_Windows_UI_Xaml_Automation_Text_1_H
#include "winrt/impl/Windows.UI.Xaml.Automation.Text.0.h"
WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Automation::Text
{
}
#endif
