# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input.Preview")

try:
    import winsdk.windows.ui.input
except ImportError:
    pass

try:
    import winsdk.windows.ui.windowmanagement
except ImportError:
    pass


InputActivationListenerPreview = _ns_module.InputActivationListenerPreview
