# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.Management.Deployment")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.management.deployment
except ImportError:
    pass

class EnterpriseEnrollmentStatus(enum.IntEnum):
    SUCCESS = 0
    CANCELLED_BY_USER = 1
    UNKNOWN_FAILURE = 2

class EnterpriseStatus(enum.IntEnum):
    ENROLLED = 0
    DISABLED = 1
    REVOKED = 2
    EXPIRED = 3

_ns_module._register_EnterpriseEnrollmentStatus(EnterpriseEnrollmentStatus)
_ns_module._register_EnterpriseStatus(EnterpriseStatus)

Enterprise = _ns_module.Enterprise
EnterpriseEnrollmentManager = _ns_module.EnterpriseEnrollmentManager
EnterpriseEnrollmentResult = _ns_module.EnterpriseEnrollmentResult
InstallationManager = _ns_module.InstallationManager
PackageInstallResult = _ns_module.PackageInstallResult
