# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Web.AtomPub")

try:
    import winsdk.windows.data.xml.dom
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.web.syndication
except ImportError:
    pass


AtomPubClient = _ns_module.AtomPubClient
ResourceCollection = _ns_module.ResourceCollection
ServiceDocument = _ns_module.ServiceDocument
Workspace = _ns_module.Workspace
