# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.ConversationalAgent")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.audio
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class ActivationSignalDetectionConfigurationCreationStatus(enum.IntEnum):
    SUCCESS = 0
    SIGNAL_ID_NOT_AVAILABLE = 1
    MODEL_ID_NOT_SUPPORTED = 2
    INVALID_SIGNAL_ID = 3
    INVALID_MODEL_ID = 4
    INVALID_DISPLAY_NAME = 5
    CONFIGURATION_ALREADY_EXISTS = 6
    CREATION_NOT_SUPPORTED = 7

class ActivationSignalDetectionConfigurationRemovalResult(enum.IntEnum):
    SUCCESS = 0
    NOT_FOUND = 1
    CURRENTLY_ENABLED = 2
    REMOVAL_NOT_SUPPORTED = 3

class ActivationSignalDetectionConfigurationSetModelDataResult(enum.IntEnum):
    SUCCESS = 0
    EMPTY_MODEL_DATA = 1
    UNSUPPORTED_FORMAT = 2
    CONFIGURATION_CURRENTLY_ENABLED = 3
    INVALID_DATA = 4
    SET_MODEL_DATA_NOT_SUPPORTED = 5
    CONFIGURATION_NOT_FOUND = 6
    UNKNOWN_ERROR = 7

class ActivationSignalDetectionConfigurationStateChangeResult(enum.IntEnum):
    SUCCESS = 0
    NO_MODEL_DATA = 1
    CONFIGURATION_NOT_FOUND = 2

class ActivationSignalDetectionTrainingDataFormat(enum.IntEnum):
    VOICE8K_HZ8_BIT_MONO = 0
    VOICE8K_HZ16_BIT_MONO = 1
    VOICE16K_HZ8_BIT_MONO = 2
    VOICE16K_HZ16_BIT_MONO = 3
    VOICE_O_E_M_DEFINED = 4
    AUDIO44K_HZ8_BIT_MONO = 5
    AUDIO44K_HZ16_BIT_MONO = 6
    AUDIO48K_HZ8_BIT_MONO = 7
    AUDIO48K_HZ16_BIT_MONO = 8
    AUDIO_O_E_M_DEFINED = 9
    OTHER_O_E_M_DEFINED = 10

class ActivationSignalDetectorKind(enum.IntEnum):
    AUDIO_PATTERN = 0
    AUDIO_IMPULSE = 1
    HARDWARE_EVENT = 2

class ActivationSignalDetectorPowerState(enum.IntEnum):
    HIGH_POWER = 0
    CONNECTED_LOW_POWER = 1
    DISCONNECTED_LOW_POWER = 2

class ConversationalAgentActivationKind(enum.IntEnum):
    VOICE_ACTIVATION_PREVIEW = 0
    FOREGROUND = 1

class ConversationalAgentActivationResult(enum.IntEnum):
    SUCCESS = 0
    AGENT_INACTIVE = 1
    SCREEN_NOT_AVAILABLE = 2
    AGENT_INTERRUPTED = 3

class ConversationalAgentSessionUpdateResponse(enum.IntEnum):
    SUCCESS = 0
    FAILED = 1

class ConversationalAgentState(enum.IntEnum):
    INACTIVE = 0
    DETECTING = 1
    LISTENING = 2
    WORKING = 3
    SPEAKING = 4
    LISTENING_AND_SPEAKING = 5

class ConversationalAgentSystemStateChangeType(enum.IntEnum):
    USER_AUTHENTICATION = 0
    SCREEN_AVAILABILITY = 1
    INDICATOR_LIGHT_AVAILABILITY = 2
    VOICE_ACTIVATION_AVAILABILITY = 3

class ConversationalAgentVoiceActivationPrerequisiteKind(enum.IntEnum):
    MICROPHONE_PERMISSION = 0
    KNOWN_AGENTS = 1
    AGENT_ALLOWED = 2
    APP_CAPABILITY = 3
    BACKGROUND_TASK_REGISTRATION = 4
    POLICY_PERMISSION = 5

class DetectionConfigurationAvailabilityChangeKind(enum.IntEnum):
    SYSTEM_RESOURCE_ACCESS = 0
    PERMISSION = 1
    LOCK_SCREEN_PERMISSION = 2

class DetectionConfigurationTrainingStatus(enum.IntEnum):
    SUCCESS = 0
    FORMAT_NOT_SUPPORTED = 1
    VOICE_TOO_QUIET = 2
    VOICE_TOO_LOUD = 3
    VOICE_TOO_FAST = 4
    VOICE_TOO_SLOW = 5
    VOICE_QUALITY_PROBLEM = 6
    TRAINING_SYSTEM_INTERNAL_ERROR = 7
    TRAINING_TIMED_OUT = 8
    CONFIGURATION_NOT_FOUND = 9

class SignalDetectorResourceKind(enum.IntEnum):
    PARALLEL_MODEL_SUPPORT = 0
    PARALLEL_MODEL_SUPPORT_FOR_AGENT = 1
    PARALLEL_SIGNAL_SUPPORT = 2
    PARALLEL_SIGNAL_SUPPORT_FOR_AGENT = 3
    DISPLAY_OFF_SUPPORT = 4
    PLUGGED_IN_POWER = 5
    DETECTOR = 6
    SUPPORTED_SLEEP_STATE = 7
    SUPPORTED_BATTERY_SAVER_STATE = 8
    SCREEN_AVAILABILITY = 9
    INPUT_HARDWARE = 10
    ACOUSTIC_ECHO_CANCELLATION = 11
    MODEL_ID_SUPPORT = 12
    DATA_CHANNEL = 13

_ns_module._register_ActivationSignalDetectionConfigurationCreationStatus(ActivationSignalDetectionConfigurationCreationStatus)
_ns_module._register_ActivationSignalDetectionConfigurationRemovalResult(ActivationSignalDetectionConfigurationRemovalResult)
_ns_module._register_ActivationSignalDetectionConfigurationSetModelDataResult(ActivationSignalDetectionConfigurationSetModelDataResult)
_ns_module._register_ActivationSignalDetectionConfigurationStateChangeResult(ActivationSignalDetectionConfigurationStateChangeResult)
_ns_module._register_ActivationSignalDetectionTrainingDataFormat(ActivationSignalDetectionTrainingDataFormat)
_ns_module._register_ActivationSignalDetectorKind(ActivationSignalDetectorKind)
_ns_module._register_ActivationSignalDetectorPowerState(ActivationSignalDetectorPowerState)
_ns_module._register_ConversationalAgentActivationKind(ConversationalAgentActivationKind)
_ns_module._register_ConversationalAgentActivationResult(ConversationalAgentActivationResult)
_ns_module._register_ConversationalAgentSessionUpdateResponse(ConversationalAgentSessionUpdateResponse)
_ns_module._register_ConversationalAgentState(ConversationalAgentState)
_ns_module._register_ConversationalAgentSystemStateChangeType(ConversationalAgentSystemStateChangeType)
_ns_module._register_ConversationalAgentVoiceActivationPrerequisiteKind(ConversationalAgentVoiceActivationPrerequisiteKind)
_ns_module._register_DetectionConfigurationAvailabilityChangeKind(DetectionConfigurationAvailabilityChangeKind)
_ns_module._register_DetectionConfigurationTrainingStatus(DetectionConfigurationTrainingStatus)
_ns_module._register_SignalDetectorResourceKind(SignalDetectorResourceKind)

ActivationSignalDetectionConfiguration = _ns_module.ActivationSignalDetectionConfiguration
ActivationSignalDetectionConfigurationCreationResult = _ns_module.ActivationSignalDetectionConfigurationCreationResult
ActivationSignalDetector = _ns_module.ActivationSignalDetector
ConversationalAgentDetectorManager = _ns_module.ConversationalAgentDetectorManager
ConversationalAgentSession = _ns_module.ConversationalAgentSession
ConversationalAgentSessionInterruptedEventArgs = _ns_module.ConversationalAgentSessionInterruptedEventArgs
ConversationalAgentSignal = _ns_module.ConversationalAgentSignal
ConversationalAgentSignalDetectedEventArgs = _ns_module.ConversationalAgentSignalDetectedEventArgs
ConversationalAgentSystemStateChangedEventArgs = _ns_module.ConversationalAgentSystemStateChangedEventArgs
DetectionConfigurationAvailabilityChangedEventArgs = _ns_module.DetectionConfigurationAvailabilityChangedEventArgs
DetectionConfigurationAvailabilityInfo = _ns_module.DetectionConfigurationAvailabilityInfo
