# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.media.capture

Self = typing.TypeVar('Self')

class VariablePhotoCapturedEventArgs(winsdk.system.Object):
    capture_time_offset: datetime.timedelta
    captured_frame_control_values: typing.Optional[winsdk.windows.media.capture.CapturedFrameControlValues]
    frame: typing.Optional[winsdk.windows.media.capture.CapturedFrame]
    used_frame_controller_index: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VariablePhotoCapturedEventArgs: ...

class VariablePhotoSequenceCapture(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VariablePhotoSequenceCapture: ...
    def finish_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def start_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def update_settings_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_photo_captured(self, handler: winsdk.windows.foundation.TypedEventHandler[VariablePhotoSequenceCapture, VariablePhotoCapturedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_photo_captured(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_stopped(self, handler: winsdk.windows.foundation.TypedEventHandler[VariablePhotoSequenceCapture, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_stopped(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

