# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Graphics.Capture")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.graphics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.security.authorization.appcapabilityaccess
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

class GraphicsCaptureAccessKind(enum.IntEnum):
    BORDERLESS = 0
    PROGRAMMATIC = 1

_ns_module._register_GraphicsCaptureAccessKind(GraphicsCaptureAccessKind)

Direct3D11CaptureFrame = _ns_module.Direct3D11CaptureFrame
Direct3D11CaptureFramePool = _ns_module.Direct3D11CaptureFramePool
GraphicsCaptureAccess = _ns_module.GraphicsCaptureAccess
GraphicsCaptureItem = _ns_module.GraphicsCaptureItem
GraphicsCapturePicker = _ns_module.GraphicsCapturePicker
GraphicsCaptureSession = _ns_module.GraphicsCaptureSession
