// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Phone_Notification_Management_0_H
#define WINRT_Windows_Phone_Notification_Management_0_H
WINRT_EXPORT namespace winrt::Windows::ApplicationModel::Appointments
{
    struct Appointment;
}
WINRT_EXPORT namespace winrt::Windows::ApplicationModel::Email
{
    struct EmailMessage;
}
WINRT_EXPORT namespace winrt::Windows::Foundation
{
}
WINRT_EXPORT namespace winrt::Windows::Foundation::Collections
{
    template <typename T> struct WINRT_IMPL_EMPTY_BASES IVectorView;
}
WINRT_EXPORT namespace winrt::Windows::Storage::Streams
{
    struct IRandomAccessStreamReference;
}
WINRT_EXPORT namespace winrt::Windows::Phone::Notification::Management
{
    enum class AccessoryNotificationType : uint32_t
    {
        None = 0,
        Phone = 0x1,
        Email = 0x2,
        Reminder = 0x4,
        Alarm = 0x8,
        Toast = 0x10,
        AppUninstalled = 0x20,
        Dnd = 0x40,
        DrivingMode = 0x80,
        BatterySaver = 0x100,
        Media = 0x200,
        CortanaTile = 0x400,
        ToastCleared = 0x800,
        CalendarChanged = 0x1000,
        VolumeChanged = 0x2000,
        EmailReadStatusChanged = 0x4000,
    };
    enum class CalendarChangedEvent : int32_t
    {
        LostEvents = 0,
        AppointmentAdded = 1,
        AppointmentChanged = 2,
        AppointmentDeleted = 3,
        CalendarAdded = 4,
        CalendarChanged = 5,
        CalendarDeleted = 6,
    };
    enum class PhoneCallAudioEndpoint : int32_t
    {
        Default = 0,
        Speaker = 1,
        Handsfree = 2,
    };
    enum class PhoneCallDirection : int32_t
    {
        Incoming = 0,
        Outgoing = 1,
    };
    enum class PhoneCallState : int32_t
    {
        Unknown = 0,
        Ringing = 1,
        Talking = 2,
        Held = 3,
        Ended = 4,
    };
    enum class PhoneCallTransport : int32_t
    {
        Cellular = 0,
        Voip = 1,
    };
    enum class PhoneLineRegistrationState : int32_t
    {
        Disconnected = 0,
        Home = 1,
        Roaming = 2,
    };
    enum class PhoneMediaType : int32_t
    {
        AudioOnly = 0,
        AudioVideo = 1,
    };
    enum class PhoneNotificationType : int32_t
    {
        NewCall = 0,
        CallChanged = 1,
        LineChanged = 2,
        PhoneCallAudioEndpointChanged = 3,
        PhoneMuteChanged = 4,
    };
    enum class PlaybackCapability : uint32_t
    {
        None = 0,
        Play = 0x1,
        Pause = 0x2,
        Stop = 0x4,
        Record = 0x8,
        FastForward = 0x10,
        Rewind = 0x20,
        Next = 0x40,
        Previous = 0x80,
        ChannelUp = 0x100,
        ChannelDown = 0x200,
    };
    enum class PlaybackCommand : int32_t
    {
        Play = 0,
        Pause = 1,
        Stop = 2,
        Record = 3,
        FastForward = 4,
        Rewind = 5,
        Next = 6,
        Previous = 7,
        ChannelUp = 8,
        ChannelDown = 9,
    };
    enum class PlaybackStatus : int32_t
    {
        None = 0,
        TrackChanged = 1,
        Stopped = 2,
        Playing = 3,
        Paused = 4,
    };
    enum class ReminderState : int32_t
    {
        Active = 0,
        Snoozed = 1,
        Dismissed = 2,
    };
    enum class VibrateState : int32_t
    {
        RingerOffVibrateOff = 0,
        RingerOffVibrateOn = 1,
        RingerOnVibrateOff = 2,
        RingerOnVibrateOn = 3,
    };
    struct IAccessoryManager;
    struct IAccessoryManager2;
    struct IAccessoryManager3;
    struct IAccessoryNotificationTriggerDetails;
    struct IAlarmNotificationTriggerDetails;
    struct IAlarmNotificationTriggerDetails2;
    struct IAppNotificationInfo;
    struct IBinaryId;
    struct ICalendarChangedNotificationTriggerDetails;
    struct ICortanaTileNotificationTriggerDetails;
    struct IEmailAccountInfo;
    struct IEmailFolderInfo;
    struct IEmailNotificationTriggerDetails;
    struct IEmailNotificationTriggerDetails2;
    struct IEmailReadNotificationTriggerDetails;
    struct IMediaControlsTriggerDetails;
    struct IMediaMetadata;
    struct IPhoneCallDetails;
    struct IPhoneLineDetails;
    struct IPhoneLineDetails2;
    struct IPhoneNotificationTriggerDetails;
    struct IReminderNotificationTriggerDetails;
    struct IReminderNotificationTriggerDetails2;
    struct ISpeedDialEntry;
    struct ITextResponse;
    struct IToastNotificationTriggerDetails;
    struct IToastNotificationTriggerDetails2;
    struct IVolumeInfo;
    struct AccessoryManager;
    struct AlarmNotificationTriggerDetails;
    struct AppNotificationInfo;
    struct BinaryId;
    struct CalendarChangedNotificationTriggerDetails;
    struct CortanaTileNotificationTriggerDetails;
    struct EmailAccountInfo;
    struct EmailFolderInfo;
    struct EmailNotificationTriggerDetails;
    struct EmailReadNotificationTriggerDetails;
    struct MediaControlsTriggerDetails;
    struct MediaMetadata;
    struct PhoneCallDetails;
    struct PhoneLineDetails;
    struct PhoneNotificationTriggerDetails;
    struct ReminderNotificationTriggerDetails;
    struct SpeedDialEntry;
    struct TextResponse;
    struct ToastNotificationTriggerDetails;
    struct VolumeInfo;
}
namespace winrt::impl
{
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAccessoryManager>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAccessoryManager2>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAccessoryManager3>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails2>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IAppNotificationInfo>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IBinaryId>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ICalendarChangedNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ICortanaTileNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IEmailAccountInfo>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IEmailFolderInfo>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails2>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IEmailReadNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IMediaControlsTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IMediaMetadata>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IPhoneCallDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails2>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IPhoneNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails2>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ISpeedDialEntry>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ITextResponse>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails2>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::IVolumeInfo>{ using type = interface_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::AccessoryManager>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::AlarmNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::AppNotificationInfo>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::BinaryId>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::CalendarChangedNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::CortanaTileNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::EmailAccountInfo>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::EmailFolderInfo>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::EmailNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::EmailReadNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::MediaControlsTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::MediaMetadata>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneCallDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneLineDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ReminderNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::SpeedDialEntry>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::TextResponse>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ToastNotificationTriggerDetails>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::VolumeInfo>{ using type = class_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::AccessoryNotificationType>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::CalendarChangedEvent>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneCallDirection>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneCallState>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneCallTransport>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneLineRegistrationState>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneMediaType>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PhoneNotificationType>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PlaybackCapability>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PlaybackCommand>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::PlaybackStatus>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::ReminderState>{ using type = enum_category; };
    template <> struct category<winrt::Windows::Phone::Notification::Management::VibrateState>{ using type = enum_category; };
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::AccessoryManager> = L"Windows.Phone.Notification.Management.AccessoryManager";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::AlarmNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.AlarmNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::AppNotificationInfo> = L"Windows.Phone.Notification.Management.AppNotificationInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::BinaryId> = L"Windows.Phone.Notification.Management.BinaryId";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::CalendarChangedNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.CalendarChangedNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::CortanaTileNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.CortanaTileNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::EmailAccountInfo> = L"Windows.Phone.Notification.Management.EmailAccountInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::EmailFolderInfo> = L"Windows.Phone.Notification.Management.EmailFolderInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::EmailNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.EmailNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::EmailReadNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.EmailReadNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::MediaControlsTriggerDetails> = L"Windows.Phone.Notification.Management.MediaControlsTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::MediaMetadata> = L"Windows.Phone.Notification.Management.MediaMetadata";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneCallDetails> = L"Windows.Phone.Notification.Management.PhoneCallDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneLineDetails> = L"Windows.Phone.Notification.Management.PhoneLineDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.PhoneNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ReminderNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.ReminderNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::SpeedDialEntry> = L"Windows.Phone.Notification.Management.SpeedDialEntry";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::TextResponse> = L"Windows.Phone.Notification.Management.TextResponse";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ToastNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.ToastNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::VolumeInfo> = L"Windows.Phone.Notification.Management.VolumeInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::AccessoryNotificationType> = L"Windows.Phone.Notification.Management.AccessoryNotificationType";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::CalendarChangedEvent> = L"Windows.Phone.Notification.Management.CalendarChangedEvent";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint> = L"Windows.Phone.Notification.Management.PhoneCallAudioEndpoint";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneCallDirection> = L"Windows.Phone.Notification.Management.PhoneCallDirection";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneCallState> = L"Windows.Phone.Notification.Management.PhoneCallState";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneCallTransport> = L"Windows.Phone.Notification.Management.PhoneCallTransport";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneLineRegistrationState> = L"Windows.Phone.Notification.Management.PhoneLineRegistrationState";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneMediaType> = L"Windows.Phone.Notification.Management.PhoneMediaType";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PhoneNotificationType> = L"Windows.Phone.Notification.Management.PhoneNotificationType";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PlaybackCapability> = L"Windows.Phone.Notification.Management.PlaybackCapability";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PlaybackCommand> = L"Windows.Phone.Notification.Management.PlaybackCommand";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::PlaybackStatus> = L"Windows.Phone.Notification.Management.PlaybackStatus";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ReminderState> = L"Windows.Phone.Notification.Management.ReminderState";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::VibrateState> = L"Windows.Phone.Notification.Management.VibrateState";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAccessoryManager> = L"Windows.Phone.Notification.Management.IAccessoryManager";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAccessoryManager2> = L"Windows.Phone.Notification.Management.IAccessoryManager2";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAccessoryManager3> = L"Windows.Phone.Notification.Management.IAccessoryManager3";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IAccessoryNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IAlarmNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails2> = L"Windows.Phone.Notification.Management.IAlarmNotificationTriggerDetails2";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IAppNotificationInfo> = L"Windows.Phone.Notification.Management.IAppNotificationInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IBinaryId> = L"Windows.Phone.Notification.Management.IBinaryId";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ICalendarChangedNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.ICalendarChangedNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ICortanaTileNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.ICortanaTileNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IEmailAccountInfo> = L"Windows.Phone.Notification.Management.IEmailAccountInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IEmailFolderInfo> = L"Windows.Phone.Notification.Management.IEmailFolderInfo";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IEmailNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails2> = L"Windows.Phone.Notification.Management.IEmailNotificationTriggerDetails2";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IEmailReadNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IEmailReadNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IMediaControlsTriggerDetails> = L"Windows.Phone.Notification.Management.IMediaControlsTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IMediaMetadata> = L"Windows.Phone.Notification.Management.IMediaMetadata";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IPhoneCallDetails> = L"Windows.Phone.Notification.Management.IPhoneCallDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails> = L"Windows.Phone.Notification.Management.IPhoneLineDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails2> = L"Windows.Phone.Notification.Management.IPhoneLineDetails2";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IPhoneNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IPhoneNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IReminderNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails2> = L"Windows.Phone.Notification.Management.IReminderNotificationTriggerDetails2";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ISpeedDialEntry> = L"Windows.Phone.Notification.Management.ISpeedDialEntry";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::ITextResponse> = L"Windows.Phone.Notification.Management.ITextResponse";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails> = L"Windows.Phone.Notification.Management.IToastNotificationTriggerDetails";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails2> = L"Windows.Phone.Notification.Management.IToastNotificationTriggerDetails2";
    template <> inline constexpr auto& name_v<winrt::Windows::Phone::Notification::Management::IVolumeInfo> = L"Windows.Phone.Notification.Management.IVolumeInfo";
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAccessoryManager>{ 0x0D04A12C,0x883D,0x4AA7,{ 0xBC,0xA7,0xFA,0x4B,0xB8,0xBF,0xFE,0xE6 } }; // 0D04A12C-883D-4AA7-BCA7-FA4BB8BFFEE6
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAccessoryManager2>{ 0xBACAD44D,0xD393,0x46C6,{ 0xB8,0x0C,0x15,0xFD,0xF4,0x4D,0x53,0x86 } }; // BACAD44D-D393-46C6-B80C-15FDF44D5386
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAccessoryManager3>{ 0x81F75137,0xEDC7,0x47E0,{ 0xB2,0xF7,0x7E,0x57,0x7C,0x83,0x3F,0x7D } }; // 81F75137-EDC7-47E0-B2F7-7E577C833F7D
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails>{ 0x6968A7D4,0xE3CA,0x49CB,{ 0x8C,0x87,0x2C,0x11,0xCD,0xFF,0x96,0x46 } }; // 6968A7D4-E3CA-49CB-8C87-2C11CDFF9646
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails>{ 0x38F5FA30,0xC738,0x4DA2,{ 0x90,0x8C,0x77,0x5D,0x83,0xC3,0x6A,0xBB } }; // 38F5FA30-C738-4DA2-908C-775D83C36ABB
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails2>{ 0xCF16E06A,0x7155,0x40FE,{ 0xA9,0xC2,0x7B,0xD2,0x12,0x7E,0xF8,0x53 } }; // CF16E06A-7155-40FE-A9C2-7BD2127EF853
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IAppNotificationInfo>{ 0x2157BEA5,0xE286,0x45D3,{ 0x9B,0xEA,0xF7,0x90,0xFC,0x21,0x6E,0x0E } }; // 2157BEA5-E286-45D3-9BEA-F790FC216E0E
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IBinaryId>{ 0x4F0DA531,0x5595,0x44B4,{ 0x91,0x81,0xCE,0x4E,0xFA,0x3F,0xC1,0x68 } }; // 4F0DA531-5595-44B4-9181-CE4EFA3FC168
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::ICalendarChangedNotificationTriggerDetails>{ 0x4B8A3BFC,0x279D,0x42AB,{ 0x9C,0x68,0x3E,0x87,0x97,0x7B,0xF2,0x16 } }; // 4B8A3BFC-279D-42AB-9C68-3E87977BF216
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::ICortanaTileNotificationTriggerDetails>{ 0xDC0F01D5,0x1489,0x46BB,{ 0xB7,0x3B,0x7F,0x90,0x06,0x7E,0xCF,0x27 } }; // DC0F01D5-1489-46BB-B73B-7F90067ECF27
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IEmailAccountInfo>{ 0xDFBC02AB,0xBDA0,0x4568,{ 0x92,0x7E,0xB2,0xED,0xE3,0x58,0x18,0xA1 } }; // DFBC02AB-BDA0-4568-927E-B2EDE35818A1
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IEmailFolderInfo>{ 0xC207150E,0xE237,0x46D6,{ 0x90,0xE6,0x4F,0x52,0x9E,0xEA,0xC1,0xE2 } }; // C207150E-E237-46D6-90E6-4F529EEAC1E2
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails>{ 0xF3B82612,0x46CF,0x4E70,{ 0x8E,0x0D,0x7B,0x2E,0x04,0xAB,0x49,0x2B } }; // F3B82612-46CF-4E70-8E0D-7B2E04AB492B
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails2>{ 0x168067E3,0xC56F,0x4EC7,{ 0xBE,0xD1,0xF7,0x34,0xE0,0x8D,0xE5,0xB2 } }; // 168067E3-C56F-4EC7-BED1-F734E08DE5B2
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IEmailReadNotificationTriggerDetails>{ 0xF5B7A087,0x06F3,0x4E3E,{ 0x8C,0x42,0x32,0x5E,0x67,0x01,0x04,0x13 } }; // F5B7A087-06F3-4E3E-8C42-325E67010413
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IMediaControlsTriggerDetails>{ 0xFAB4648B,0xAE45,0x4548,{ 0x91,0xCA,0x4A,0xB0,0x54,0x8E,0x33,0xB5 } }; // FAB4648B-AE45-4548-91CA-4AB0548E33B5
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IMediaMetadata>{ 0x9B50DDF7,0xBB6C,0x4330,{ 0xB3,0xCD,0x07,0x04,0xA5,0x4C,0xDB,0x80 } }; // 9B50DDF7-BB6C-4330-B3CD-0704A54CDB80
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IPhoneCallDetails>{ 0x0C1B6F53,0xF071,0x483E,{ 0xBF,0x33,0xEB,0xD4,0x4B,0x72,0x44,0x47 } }; // 0C1B6F53-F071-483E-BF33-EBD44B724447
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails>{ 0x47EB32DC,0x33ED,0x49B9,{ 0x99,0x5C,0xA2,0x96,0xBA,0xC8,0x2B,0x77 } }; // 47EB32DC-33ED-49B9-995C-A296BAC82B77
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails2>{ 0xB30CD77D,0x0147,0x498C,{ 0x82,0x41,0xBF,0x0C,0xAB,0xC6,0x0A,0x25 } }; // B30CD77D-0147-498C-8241-BF0CABC60A25
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IPhoneNotificationTriggerDetails>{ 0xCCC2FDF7,0x09C3,0x4118,{ 0x91,0xBC,0xCA,0x63,0x23,0xA8,0xD3,0x83 } }; // CCC2FDF7-09C3-4118-91BC-CA6323A8D383
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails>{ 0x5BDDAA5D,0x9F61,0x4BF0,{ 0x9F,0xEB,0x10,0x50,0x2B,0xC0,0xB0,0xC2 } }; // 5BDDAA5D-9F61-4BF0-9FEB-10502BC0B0C2
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails2>{ 0xE715F9C0,0x504D,0x4C0F,{ 0xA6,0xB3,0xBC,0xB9,0x72,0x2C,0x6C,0xDD } }; // E715F9C0-504D-4C0F-A6B3-BCB9722C6CDD
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::ISpeedDialEntry>{ 0x9240B6DB,0x872C,0x46DC,{ 0xB6,0x2A,0xBE,0x45,0x41,0xB1,0x66,0xF8 } }; // 9240B6DB-872C-46DC-B62A-BE4541B166F8
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::ITextResponse>{ 0xE9CB74C3,0x2457,0x4CDB,{ 0x81,0x10,0x72,0xF5,0xE8,0xE8,0x83,0xE8 } }; // E9CB74C3-2457-4CDB-8110-72F5E8E883E8
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails>{ 0xC9314895,0x4E6D,0x4E9D,{ 0xAF,0xEC,0x9E,0x92,0x1B,0x87,0x5A,0xE8 } }; // C9314895-4E6D-4E9D-AFEC-9E921B875AE8
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails2>{ 0x3E0479DD,0xCAC4,0x4F60,{ 0xAF,0xA3,0xB9,0x25,0xD9,0xD8,0x3C,0x93 } }; // 3E0479DD-CAC4-4F60-AFA3-B925D9D83C93
    template <> inline constexpr guid guid_v<winrt::Windows::Phone::Notification::Management::IVolumeInfo>{ 0x944DD118,0x7704,0x4481,{ 0xB9,0x2E,0xD3,0xED,0x3E,0xCE,0x63,0x22 } }; // 944DD118-7704-4481-B92E-D3ED3ECE6322
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::AlarmNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::AppNotificationInfo>{ using type = winrt::Windows::Phone::Notification::Management::IAppNotificationInfo; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::BinaryId>{ using type = winrt::Windows::Phone::Notification::Management::IBinaryId; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::CalendarChangedNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::ICalendarChangedNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::CortanaTileNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::ICortanaTileNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::EmailAccountInfo>{ using type = winrt::Windows::Phone::Notification::Management::IEmailAccountInfo; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::EmailFolderInfo>{ using type = winrt::Windows::Phone::Notification::Management::IEmailFolderInfo; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::EmailNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::EmailReadNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IEmailReadNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::MediaControlsTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IMediaControlsTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::MediaMetadata>{ using type = winrt::Windows::Phone::Notification::Management::IMediaMetadata; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::PhoneCallDetails>{ using type = winrt::Windows::Phone::Notification::Management::IPhoneCallDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::PhoneLineDetails>{ using type = winrt::Windows::Phone::Notification::Management::IPhoneLineDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::PhoneNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IPhoneNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::ReminderNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::SpeedDialEntry>{ using type = winrt::Windows::Phone::Notification::Management::ISpeedDialEntry; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::TextResponse>{ using type = winrt::Windows::Phone::Notification::Management::ITextResponse; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::ToastNotificationTriggerDetails>{ using type = winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails; };
    template <> struct default_interface<winrt::Windows::Phone::Notification::Management::VolumeInfo>{ using type = winrt::Windows::Phone::Notification::Management::IVolumeInfo; };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAccessoryManager>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall RegisterAccessoryApp(void**) noexcept = 0;
            virtual int32_t __stdcall GetNextTriggerDetails(void**) noexcept = 0;
            virtual int32_t __stdcall ProcessTriggerDetails(void*) noexcept = 0;
            virtual int32_t __stdcall get_PhoneLineDetails(void**) noexcept = 0;
            virtual int32_t __stdcall GetPhoneLineDetails(winrt::guid, void**) noexcept = 0;
            virtual int32_t __stdcall AcceptPhoneCall(uint32_t) noexcept = 0;
            virtual int32_t __stdcall AcceptPhoneCallOnEndpoint(uint32_t, int32_t) noexcept = 0;
            virtual int32_t __stdcall AcceptPhoneCallWithVideo(uint32_t) noexcept = 0;
            virtual int32_t __stdcall AcceptPhoneCallWithVideoOnAudioEndpoint(uint32_t, int32_t) noexcept = 0;
            virtual int32_t __stdcall RejectPhoneCall(uint32_t) noexcept = 0;
            virtual int32_t __stdcall RejectPhoneCallWithText(uint32_t, uint32_t) noexcept = 0;
            virtual int32_t __stdcall MakePhoneCall(winrt::guid, void*) noexcept = 0;
            virtual int32_t __stdcall MakePhoneCallOnAudioEndpoint(winrt::guid, void*, int32_t) noexcept = 0;
            virtual int32_t __stdcall MakePhoneCallWithVideo(winrt::guid, void*) noexcept = 0;
            virtual int32_t __stdcall MakePhoneCallWithVideoOnAudioEndpoint(winrt::guid, void*, int32_t) noexcept = 0;
            virtual int32_t __stdcall SwapPhoneCalls(uint32_t, uint32_t) noexcept = 0;
            virtual int32_t __stdcall HoldPhoneCall(uint32_t, bool) noexcept = 0;
            virtual int32_t __stdcall EndPhoneCall(uint32_t) noexcept = 0;
            virtual int32_t __stdcall put_PhoneMute(bool) noexcept = 0;
            virtual int32_t __stdcall get_PhoneMute(bool*) noexcept = 0;
            virtual int32_t __stdcall put_PhoneCallAudioEndpoint(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_PhoneCallAudioEndpoint(int32_t*) noexcept = 0;
            virtual int32_t __stdcall SnoozeAlarm(winrt::guid) noexcept = 0;
            virtual int32_t __stdcall SnoozeAlarmForSpecifiedTime(winrt::guid, int64_t) noexcept = 0;
            virtual int32_t __stdcall DismissAlarm(winrt::guid) noexcept = 0;
            virtual int32_t __stdcall SnoozeReminder(winrt::guid) noexcept = 0;
            virtual int32_t __stdcall SnoozeReminderForSpecifiedTime(winrt::guid, int64_t) noexcept = 0;
            virtual int32_t __stdcall DismissReminder(winrt::guid) noexcept = 0;
            virtual int32_t __stdcall GetMediaMetadata(void**) noexcept = 0;
            virtual int32_t __stdcall get_MediaPlaybackCapabilities(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_MediaPlaybackStatus(int32_t*) noexcept = 0;
            virtual int32_t __stdcall PerformMediaPlaybackCommand(int32_t) noexcept = 0;
            virtual int32_t __stdcall get_DoNotDisturbEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall get_DrivingModeEnabled(bool*) noexcept = 0;
            virtual int32_t __stdcall get_BatterySaverState(bool*) noexcept = 0;
            virtual int32_t __stdcall GetApps(void**) noexcept = 0;
            virtual int32_t __stdcall EnableNotificationsForApplication(void*) noexcept = 0;
            virtual int32_t __stdcall DisableNotificationsForApplication(void*) noexcept = 0;
            virtual int32_t __stdcall IsNotificationEnabledForApplication(void*, bool*) noexcept = 0;
            virtual int32_t __stdcall GetEnabledAccessoryNotificationTypes(int32_t*) noexcept = 0;
            virtual int32_t __stdcall EnableAccessoryNotificationTypes(int32_t) noexcept = 0;
            virtual int32_t __stdcall DisableAllAccessoryNotificationTypes() noexcept = 0;
            virtual int32_t __stdcall GetUserConsent(bool*) noexcept = 0;
            virtual int32_t __stdcall GetAppIcon(void*, void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAccessoryManager2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall RingDevice() noexcept = 0;
            virtual int32_t __stdcall get_SpeedDialList(void**) noexcept = 0;
            virtual int32_t __stdcall ClearToast(void*) noexcept = 0;
            virtual int32_t __stdcall get_IsPhonePinLocked(bool*) noexcept = 0;
            virtual int32_t __stdcall IncreaseVolume(int32_t) noexcept = 0;
            virtual int32_t __stdcall DecreaseVolume(int32_t) noexcept = 0;
            virtual int32_t __stdcall SetMute(bool) noexcept = 0;
            virtual int32_t __stdcall SetRingerVibrate(bool, bool) noexcept = 0;
            virtual int32_t __stdcall get_VolumeInfo(void**) noexcept = 0;
            virtual int32_t __stdcall GetAllEmailAccounts(void**) noexcept = 0;
            virtual int32_t __stdcall GetFolders(void*, void**) noexcept = 0;
            virtual int32_t __stdcall EnableEmailNotificationEmailAccount(void*) noexcept = 0;
            virtual int32_t __stdcall DisableEmailNotificationEmailAccount(void*) noexcept = 0;
            virtual int32_t __stdcall EnableEmailNotificationFolderFilter(void*, void*) noexcept = 0;
            virtual int32_t __stdcall UpdateEmailReadStatus(void*, bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAccessoryManager3>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall SnoozeAlarmByInstanceId(void*) noexcept = 0;
            virtual int32_t __stdcall DismissAlarmByInstanceId(void*) noexcept = 0;
            virtual int32_t __stdcall SnoozeReminderByInstanceId(void*) noexcept = 0;
            virtual int32_t __stdcall DismissReminderByInstanceId(void*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TimeCreated(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_AppDisplayName(void**) noexcept = 0;
            virtual int32_t __stdcall get_AppId(void**) noexcept = 0;
            virtual int32_t __stdcall get_AccessoryNotificationType(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_StartedProcessing(bool*) noexcept = 0;
            virtual int32_t __stdcall put_StartedProcessing(bool) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AlarmId(winrt::guid*) noexcept = 0;
            virtual int32_t __stdcall get_Title(void**) noexcept = 0;
            virtual int32_t __stdcall get_Timestamp(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_ReminderState(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InstanceId(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IAppNotificationInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Id(void**) noexcept = 0;
            virtual int32_t __stdcall get_Name(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IBinaryId>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Id(uint8_t*) noexcept = 0;
            virtual int32_t __stdcall get_Length(uint32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::ICalendarChangedNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_EventType(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_ItemId(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::ICortanaTileNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_TileId(void**) noexcept = 0;
            virtual int32_t __stdcall get_Content(void**) noexcept = 0;
            virtual int32_t __stdcall get_LargeContent1(void**) noexcept = 0;
            virtual int32_t __stdcall get_LargeContent2(void**) noexcept = 0;
            virtual int32_t __stdcall get_EmphasizedText(void**) noexcept = 0;
            virtual int32_t __stdcall get_NonWrappedSmallContent1(void**) noexcept = 0;
            virtual int32_t __stdcall get_NonWrappedSmallContent2(void**) noexcept = 0;
            virtual int32_t __stdcall get_NonWrappedSmallContent3(void**) noexcept = 0;
            virtual int32_t __stdcall get_NonWrappedSmallContent4(void**) noexcept = 0;
            virtual int32_t __stdcall get_Source(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IEmailAccountInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisplayName(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsNotificationEnabled(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IEmailFolderInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_DisplayName(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsNotificationEnabled(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AccountName(void**) noexcept = 0;
            virtual int32_t __stdcall get_ParentFolderName(void**) noexcept = 0;
            virtual int32_t __stdcall get_SenderName(void**) noexcept = 0;
            virtual int32_t __stdcall get_SenderAddress(void**) noexcept = 0;
            virtual int32_t __stdcall get_EmailMessage(void**) noexcept = 0;
            virtual int32_t __stdcall get_Timestamp(int64_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_MessageEntryId(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IEmailReadNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_AccountName(void**) noexcept = 0;
            virtual int32_t __stdcall get_ParentFolderName(void**) noexcept = 0;
            virtual int32_t __stdcall get_MessageEntryId(void**) noexcept = 0;
            virtual int32_t __stdcall get_IsRead(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IMediaControlsTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_PlaybackStatus(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_MediaMetadata(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IMediaMetadata>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Title(void**) noexcept = 0;
            virtual int32_t __stdcall get_Subtitle(void**) noexcept = 0;
            virtual int32_t __stdcall get_Artist(void**) noexcept = 0;
            virtual int32_t __stdcall get_Album(void**) noexcept = 0;
            virtual int32_t __stdcall get_Track(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Duration(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_Thumbnail(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IPhoneCallDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_PhoneLine(winrt::guid*) noexcept = 0;
            virtual int32_t __stdcall get_CallId(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_CallTransport(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_CallMediaType(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_CallDirection(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_State(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_ConferenceCallId(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_StartTime(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_EndTime(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_PhoneNumber(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContactName(void**) noexcept = 0;
            virtual int32_t __stdcall get_PresetTextResponses(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_LineId(winrt::guid*) noexcept = 0;
            virtual int32_t __stdcall get_DisplayName(void**) noexcept = 0;
            virtual int32_t __stdcall get_LineNumber(void**) noexcept = 0;
            virtual int32_t __stdcall get_DefaultOutgoingLine(bool*) noexcept = 0;
            virtual int32_t __stdcall get_VoicemailCount(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_RegistrationState(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_MissedCallCount(uint32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IPhoneNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_PhoneNotificationType(int32_t*) noexcept = 0;
            virtual int32_t __stdcall get_CallDetails(void**) noexcept = 0;
            virtual int32_t __stdcall get_PhoneLineChangedId(winrt::guid*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_ReminderId(winrt::guid*) noexcept = 0;
            virtual int32_t __stdcall get_Title(void**) noexcept = 0;
            virtual int32_t __stdcall get_Description(void**) noexcept = 0;
            virtual int32_t __stdcall get_Details(void**) noexcept = 0;
            virtual int32_t __stdcall get_Timestamp(int64_t*) noexcept = 0;
            virtual int32_t __stdcall get_Appointment(void**) noexcept = 0;
            virtual int32_t __stdcall get_ReminderState(int32_t*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InstanceId(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::ISpeedDialEntry>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_PhoneNumber(void**) noexcept = 0;
            virtual int32_t __stdcall get_NumberType(void**) noexcept = 0;
            virtual int32_t __stdcall get_ContactName(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::ITextResponse>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Id(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_Content(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_Text1(void**) noexcept = 0;
            virtual int32_t __stdcall get_Text2(void**) noexcept = 0;
            virtual int32_t __stdcall get_Text3(void**) noexcept = 0;
            virtual int32_t __stdcall get_Text4(void**) noexcept = 0;
            virtual int32_t __stdcall get_SuppressPopup(bool*) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails2>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_InstanceId(void**) noexcept = 0;
        };
    };
    template <> struct abi<winrt::Windows::Phone::Notification::Management::IVolumeInfo>
    {
        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
        {
            virtual int32_t __stdcall get_SystemVolume(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_CallVolume(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_MediaVolume(uint32_t*) noexcept = 0;
            virtual int32_t __stdcall get_IsMuted(bool*) noexcept = 0;
            virtual int32_t __stdcall get_IsVibrateEnabled(int32_t*) noexcept = 0;
        };
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAccessoryManager
    {
        auto RegisterAccessoryApp() const;
        auto GetNextTriggerDetails() const;
        auto ProcessTriggerDetails(winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails const& pDetails) const;
        [[nodiscard]] auto PhoneLineDetails() const;
        auto GetPhoneLineDetails(winrt::guid const& phoneLine) const;
        auto AcceptPhoneCall(uint32_t phoneCallId) const;
        auto AcceptPhoneCall(uint32_t phoneCallId, winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint const& endPoint) const;
        auto AcceptPhoneCallWithVideo(uint32_t phoneCallId) const;
        auto AcceptPhoneCallWithVideo(uint32_t phoneCallId, winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint const& endPoint) const;
        auto RejectPhoneCall(uint32_t phoneCallId) const;
        auto RejectPhoneCall(uint32_t phoneCallId, uint32_t textResponseID) const;
        auto MakePhoneCall(winrt::guid const& phoneLine, param::hstring const& phoneNumber) const;
        auto MakePhoneCall(winrt::guid const& phoneLine, param::hstring const& phoneNumber, winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint const& endPoint) const;
        auto MakePhoneCallWithVideo(winrt::guid const& phoneLine, param::hstring const& phoneNumber) const;
        auto MakePhoneCallWithVideo(winrt::guid const& phoneLine, param::hstring const& phoneNumber, winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint const& endPoint) const;
        auto SwapPhoneCalls(uint32_t phoneCallIdToHold, uint32_t phoneCallIdOnHold) const;
        auto HoldPhoneCall(uint32_t phoneCallId, bool holdCall) const;
        auto EndPhoneCall(uint32_t phoneCallId) const;
        auto PhoneMute(bool value) const;
        [[nodiscard]] auto PhoneMute() const;
        auto PhoneCallAudioEndpoint(winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint const& value) const;
        [[nodiscard]] auto PhoneCallAudioEndpoint() const;
        auto SnoozeAlarm(winrt::guid const& alarmId) const;
        auto SnoozeAlarm(winrt::guid const& alarmId, winrt::Windows::Foundation::TimeSpan const& timeSpan) const;
        auto DismissAlarm(winrt::guid const& alarmId) const;
        auto SnoozeReminder(winrt::guid const& reminderId) const;
        auto SnoozeReminder(winrt::guid const& reminderId, winrt::Windows::Foundation::TimeSpan const& timeSpan) const;
        auto DismissReminder(winrt::guid const& reminderId) const;
        auto GetMediaMetadata() const;
        [[nodiscard]] auto MediaPlaybackCapabilities() const;
        [[nodiscard]] auto MediaPlaybackStatus() const;
        auto PerformMediaPlaybackCommand(winrt::Windows::Phone::Notification::Management::PlaybackCommand const& command) const;
        [[nodiscard]] auto DoNotDisturbEnabled() const;
        [[nodiscard]] auto DrivingModeEnabled() const;
        [[nodiscard]] auto BatterySaverState() const;
        auto GetApps() const;
        auto EnableNotificationsForApplication(param::hstring const& appId) const;
        auto DisableNotificationsForApplication(param::hstring const& appId) const;
        auto IsNotificationEnabledForApplication(param::hstring const& appId) const;
        auto GetEnabledAccessoryNotificationTypes() const;
        auto EnableAccessoryNotificationTypes(int32_t accessoryNotificationTypes) const;
        auto DisableAllAccessoryNotificationTypes() const;
        auto GetUserConsent() const;
        auto GetAppIcon(param::hstring const& appId) const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAccessoryManager>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAccessoryManager<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAccessoryManager2
    {
        auto RingDevice() const;
        [[nodiscard]] auto SpeedDialList() const;
        auto ClearToast(param::hstring const& instanceId) const;
        [[nodiscard]] auto IsPhonePinLocked() const;
        auto IncreaseVolume(int32_t step) const;
        auto DecreaseVolume(int32_t step) const;
        auto SetMute(bool mute) const;
        auto SetRingerVibrate(bool ringer, bool vibrate) const;
        [[nodiscard]] auto VolumeInfo() const;
        auto GetAllEmailAccounts() const;
        auto GetFolders(param::hstring const& emailAccount) const;
        auto EnableEmailNotificationEmailAccount(param::hstring const& emailAccount) const;
        auto DisableEmailNotificationEmailAccount(param::hstring const& emailAccount) const;
        auto EnableEmailNotificationFolderFilter(param::hstring const& emailAccount, param::vector_view<hstring> const& folders) const;
        auto UpdateEmailReadStatus(winrt::Windows::Phone::Notification::Management::BinaryId const& messageEntryId, bool isRead) const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAccessoryManager2>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAccessoryManager2<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAccessoryManager3
    {
        auto SnoozeAlarmByInstanceId(param::hstring const& instanceId) const;
        auto DismissAlarmByInstanceId(param::hstring const& instanceId) const;
        auto SnoozeReminderByInstanceId(param::hstring const& instanceId) const;
        auto DismissReminderByInstanceId(param::hstring const& instanceId) const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAccessoryManager3>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAccessoryManager3<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAccessoryNotificationTriggerDetails
    {
        [[nodiscard]] auto TimeCreated() const;
        [[nodiscard]] auto AppDisplayName() const;
        [[nodiscard]] auto AppId() const;
        [[nodiscard]] auto AccessoryNotificationType() const;
        [[nodiscard]] auto StartedProcessing() const;
        auto StartedProcessing(bool value) const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAccessoryNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAlarmNotificationTriggerDetails
    {
        [[nodiscard]] auto AlarmId() const;
        [[nodiscard]] auto Title() const;
        [[nodiscard]] auto Timestamp() const;
        [[nodiscard]] auto ReminderState() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAlarmNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAlarmNotificationTriggerDetails2
    {
        [[nodiscard]] auto InstanceId() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAlarmNotificationTriggerDetails2>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAlarmNotificationTriggerDetails2<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IAppNotificationInfo
    {
        [[nodiscard]] auto Id() const;
        [[nodiscard]] auto Name() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IAppNotificationInfo>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IAppNotificationInfo<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IBinaryId
    {
        [[nodiscard]] auto Id() const;
        [[nodiscard]] auto Length() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IBinaryId>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IBinaryId<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_ICalendarChangedNotificationTriggerDetails
    {
        [[nodiscard]] auto EventType() const;
        [[nodiscard]] auto ItemId() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::ICalendarChangedNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_ICalendarChangedNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_ICortanaTileNotificationTriggerDetails
    {
        [[nodiscard]] auto TileId() const;
        [[nodiscard]] auto Content() const;
        [[nodiscard]] auto LargeContent1() const;
        [[nodiscard]] auto LargeContent2() const;
        [[nodiscard]] auto EmphasizedText() const;
        [[nodiscard]] auto NonWrappedSmallContent1() const;
        [[nodiscard]] auto NonWrappedSmallContent2() const;
        [[nodiscard]] auto NonWrappedSmallContent3() const;
        [[nodiscard]] auto NonWrappedSmallContent4() const;
        [[nodiscard]] auto Source() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::ICortanaTileNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_ICortanaTileNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IEmailAccountInfo
    {
        [[nodiscard]] auto DisplayName() const;
        [[nodiscard]] auto IsNotificationEnabled() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IEmailAccountInfo>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IEmailAccountInfo<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IEmailFolderInfo
    {
        [[nodiscard]] auto DisplayName() const;
        [[nodiscard]] auto IsNotificationEnabled() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IEmailFolderInfo>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IEmailFolderInfo<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IEmailNotificationTriggerDetails
    {
        [[nodiscard]] auto AccountName() const;
        [[nodiscard]] auto ParentFolderName() const;
        [[nodiscard]] auto SenderName() const;
        [[nodiscard]] auto SenderAddress() const;
        [[nodiscard]] auto EmailMessage() const;
        [[nodiscard]] auto Timestamp() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IEmailNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IEmailNotificationTriggerDetails2
    {
        [[nodiscard]] auto MessageEntryId() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IEmailNotificationTriggerDetails2>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IEmailNotificationTriggerDetails2<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IEmailReadNotificationTriggerDetails
    {
        [[nodiscard]] auto AccountName() const;
        [[nodiscard]] auto ParentFolderName() const;
        [[nodiscard]] auto MessageEntryId() const;
        [[nodiscard]] auto IsRead() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IEmailReadNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IEmailReadNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IMediaControlsTriggerDetails
    {
        [[nodiscard]] auto PlaybackStatus() const;
        [[nodiscard]] auto MediaMetadata() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IMediaControlsTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IMediaControlsTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IMediaMetadata
    {
        [[nodiscard]] auto Title() const;
        [[nodiscard]] auto Subtitle() const;
        [[nodiscard]] auto Artist() const;
        [[nodiscard]] auto Album() const;
        [[nodiscard]] auto Track() const;
        [[nodiscard]] auto Duration() const;
        [[nodiscard]] auto Thumbnail() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IMediaMetadata>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IMediaMetadata<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IPhoneCallDetails
    {
        [[nodiscard]] auto PhoneLine() const;
        [[nodiscard]] auto CallId() const;
        [[nodiscard]] auto CallTransport() const;
        [[nodiscard]] auto CallMediaType() const;
        [[nodiscard]] auto CallDirection() const;
        [[nodiscard]] auto State() const;
        [[nodiscard]] auto ConferenceCallId() const;
        [[nodiscard]] auto StartTime() const;
        [[nodiscard]] auto EndTime() const;
        [[nodiscard]] auto PhoneNumber() const;
        [[nodiscard]] auto ContactName() const;
        [[nodiscard]] auto PresetTextResponses() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IPhoneCallDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IPhoneCallDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IPhoneLineDetails
    {
        [[nodiscard]] auto LineId() const;
        [[nodiscard]] auto DisplayName() const;
        [[nodiscard]] auto LineNumber() const;
        [[nodiscard]] auto DefaultOutgoingLine() const;
        [[nodiscard]] auto VoicemailCount() const;
        [[nodiscard]] auto RegistrationState() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IPhoneLineDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IPhoneLineDetails2
    {
        [[nodiscard]] auto MissedCallCount() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IPhoneLineDetails2>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IPhoneLineDetails2<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IPhoneNotificationTriggerDetails
    {
        [[nodiscard]] auto PhoneNotificationType() const;
        [[nodiscard]] auto CallDetails() const;
        [[nodiscard]] auto PhoneLineChangedId() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IPhoneNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IPhoneNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IReminderNotificationTriggerDetails
    {
        [[nodiscard]] auto ReminderId() const;
        [[nodiscard]] auto Title() const;
        [[nodiscard]] auto Description() const;
        [[nodiscard]] auto Details() const;
        [[nodiscard]] auto Timestamp() const;
        [[nodiscard]] auto Appointment() const;
        [[nodiscard]] auto ReminderState() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IReminderNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IReminderNotificationTriggerDetails2
    {
        [[nodiscard]] auto InstanceId() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IReminderNotificationTriggerDetails2>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IReminderNotificationTriggerDetails2<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_ISpeedDialEntry
    {
        [[nodiscard]] auto PhoneNumber() const;
        [[nodiscard]] auto NumberType() const;
        [[nodiscard]] auto ContactName() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::ISpeedDialEntry>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_ISpeedDialEntry<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_ITextResponse
    {
        [[nodiscard]] auto Id() const;
        [[nodiscard]] auto Content() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::ITextResponse>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_ITextResponse<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IToastNotificationTriggerDetails
    {
        [[nodiscard]] auto Text1() const;
        [[nodiscard]] auto Text2() const;
        [[nodiscard]] auto Text3() const;
        [[nodiscard]] auto Text4() const;
        [[nodiscard]] auto SuppressPopup() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IToastNotificationTriggerDetails<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IToastNotificationTriggerDetails2
    {
        [[nodiscard]] auto InstanceId() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IToastNotificationTriggerDetails2>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IToastNotificationTriggerDetails2<D>;
    };
    template <typename D>
    struct consume_Windows_Phone_Notification_Management_IVolumeInfo
    {
        [[nodiscard]] auto SystemVolume() const;
        [[nodiscard]] auto CallVolume() const;
        [[nodiscard]] auto MediaVolume() const;
        [[nodiscard]] auto IsMuted() const;
        [[nodiscard]] auto IsVibrateEnabled() const;
    };
    template <> struct consume<winrt::Windows::Phone::Notification::Management::IVolumeInfo>
    {
        template <typename D> using type = consume_Windows_Phone_Notification_Management_IVolumeInfo<D>;
    };
}
#endif
