# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Security.Cryptography")

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class BinaryStringEncoding(enum.IntEnum):
    UTF8 = 0
    UTF16_L_E = 1
    UTF16_B_E = 2

_ns_module._register_BinaryStringEncoding(BinaryStringEncoding)

CryptographicBuffer = _ns_module.CryptographicBuffer
