// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Media.h")
#include "py.Windows.Media.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Media.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Media.Control.h>

namespace py::proj::Windows::Media::Control
{}

namespace py::impl::Windows::Media::Control
{}

namespace py::wrapper::Windows::Media::Control
{
    using CurrentSessionChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Control::CurrentSessionChangedEventArgs>;
    using GlobalSystemMediaTransportControlsSession = py::winrt_wrapper<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSession>;
    using GlobalSystemMediaTransportControlsSessionManager = py::winrt_wrapper<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionManager>;
    using GlobalSystemMediaTransportControlsSessionMediaProperties = py::winrt_wrapper<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionMediaProperties>;
    using GlobalSystemMediaTransportControlsSessionPlaybackControls = py::winrt_wrapper<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionPlaybackControls>;
    using GlobalSystemMediaTransportControlsSessionPlaybackInfo = py::winrt_wrapper<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionPlaybackInfo>;
    using GlobalSystemMediaTransportControlsSessionTimelineProperties = py::winrt_wrapper<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionTimelineProperties>;
    using MediaPropertiesChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Control::MediaPropertiesChangedEventArgs>;
    using PlaybackInfoChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Control::PlaybackInfoChangedEventArgs>;
    using SessionsChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Control::SessionsChangedEventArgs>;
    using TimelinePropertiesChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Control::TimelinePropertiesChangedEventArgs>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionPlaybackStatus> = "i";


    template<>
    struct py_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionPlaybackStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::CurrentSessionChangedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSession>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionManager>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionMediaProperties>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionPlaybackControls>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionPlaybackInfo>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::GlobalSystemMediaTransportControlsSessionTimelineProperties>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::MediaPropertiesChangedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::PlaybackInfoChangedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::SessionsChangedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Media::Control::TimelinePropertiesChangedEventArgs>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
