# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI")


Color = _ns_module.Color
WindowId = _ns_module.WindowId
ColorHelper = _ns_module.ColorHelper
Colors = _ns_module.Colors
UIContentRoot = _ns_module.UIContentRoot
UIContext = _ns_module.UIContext
