# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.storage

Self = typing.TypeVar('Self')

class ApplicationDataManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ApplicationDataManager: ...
    @staticmethod
    def create_for_package_family(package_family_name: str) -> typing.Optional[winsdk.windows.storage.ApplicationData]: ...

