# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.data.xml.dom

Self = typing.TypeVar('Self')

class XsltProcessor(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XsltProcessor: ...
    def __new__(cls: typing.Type[XsltProcessor], document: typing.Optional[winsdk.windows.data.xml.dom.XmlDocument]) -> XsltProcessor:...
    def transform_to_document(self, input_node: typing.Optional[winsdk.windows.data.xml.dom.IXmlNode]) -> typing.Optional[winsdk.windows.data.xml.dom.XmlDocument]: ...
    def transform_to_string(self, input_node: typing.Optional[winsdk.windows.data.xml.dom.IXmlNode]) -> str: ...

