// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Phone.System.UserProfile.GameServices.Core.h>

namespace py::proj::Windows::Phone::System::UserProfile::GameServices::Core
{}

namespace py::impl::Windows::Phone::System::UserProfile::GameServices::Core
{}

namespace py::wrapper::Windows::Phone::System::UserProfile::GameServices::Core
{
    using GameService = py::winrt_wrapper<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameService>;
    using GameServicePropertyCollection = py::winrt_wrapper<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameServicePropertyCollection>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameServiceGameOutcome> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameServiceScoreKind> = "i";


    template<>
    struct py_type<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameServiceGameOutcome>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameServiceScoreKind>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameService>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Phone::System::UserProfile::GameServices::Core::GameServicePropertyCollection>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
