# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Core.Preview")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.ui.windowmanagement
except ImportError:
    pass


CoreAppWindowPreview = _ns_module.CoreAppWindowPreview
SystemNavigationCloseRequestedPreviewEventArgs = _ns_module.SystemNavigationCloseRequestedPreviewEventArgs
SystemNavigationManagerPreview = _ns_module.SystemNavigationManagerPreview
