// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"


#include <winrt/Windows.Phone.System.Profile.h>

namespace py::proj::Windows::Phone::System::Profile
{}

namespace py::impl::Windows::Phone::System::Profile
{}

namespace py::wrapper::Windows::Phone::System::Profile
{
    using RetailMode = py::winrt_wrapper<winrt::Windows::Phone::System::Profile::RetailMode>;
}

namespace py
{

    template<>
    struct winrt_type<winrt::Windows::Phone::System::Profile::RetailMode>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
