// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Storage.h")
#include "py.Windows.Storage.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Storage.h>
#include <winrt/Windows.Storage.Streams.h>
#include <winrt/Windows.UI.h>

#include <winrt/Windows.ApplicationModel.Resources.Core.h>

namespace py::proj::Windows::ApplicationModel::Resources::Core
{}

namespace py::impl::Windows::ApplicationModel::Resources::Core
{}

namespace py::wrapper::Windows::ApplicationModel::Resources::Core
{
    using NamedResource = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::NamedResource>;
    using ResourceCandidate = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceCandidate>;
    using ResourceCandidateVectorView = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceCandidateVectorView>;
    using ResourceContext = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceContext>;
    using ResourceContextLanguagesVectorView = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceContextLanguagesVectorView>;
    using ResourceManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceManager>;
    using ResourceMap = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceMap>;
    using ResourceMapIterator = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceMapIterator>;
    using ResourceMapMapView = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceMapMapView>;
    using ResourceMapMapViewIterator = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceMapMapViewIterator>;
    using ResourceQualifier = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifier>;
    using ResourceQualifierMapView = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierMapView>;
    using ResourceQualifierObservableMap = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierObservableMap>;
    using ResourceQualifierVectorView = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierVectorView>;
    using ResourceLayoutInfo = py::winrt_struct_wrapper<winrt::Windows::ApplicationModel::Resources::Core::ResourceLayoutInfo>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Resources::Core::ResourceCandidateKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierPersistence> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Resources::Core::ResourceLayoutInfo> = "T{I:major_version:I:minor_version:I:resource_subtree_count:I:named_resource_count:i:checksum:}";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceCandidateKind>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierPersistence>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::NamedResource>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceCandidate>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceCandidateVectorView>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceContext>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceContextLanguagesVectorView>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceManager>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceMap>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceMapIterator>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceMapMapView>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceMapMapViewIterator>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifier>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierMapView>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierObservableMap>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceQualifierVectorView>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::ApplicationModel::Resources::Core::ResourceLayoutInfo>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
    template<>
    struct converter<winrt::Windows::ApplicationModel::Resources::Core::ResourceLayoutInfo>
    {
        static PyObject* convert(winrt::Windows::ApplicationModel::Resources::Core::ResourceLayoutInfo instance) noexcept;
        static winrt::Windows::ApplicationModel::Resources::Core::ResourceLayoutInfo convert_to(PyObject* obj);
    };

}
