# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

Self = typing.TypeVar('Self')

class DeviceLockdownProfile(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceLockdownProfile: ...
    @staticmethod
    def apply_lockdown_profile_async(profile_i_d: winsdk.system.Guid) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def get_current_lockdown_profile() -> winsdk.system.Guid: ...
    @staticmethod
    def get_lockdown_profile_information(profile_i_d: winsdk.system.Guid) -> typing.Optional[DeviceLockdownProfileInformation]: ...
    @staticmethod
    def get_supported_lockdown_profiles() -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Guid]]: ...

class DeviceLockdownProfileInformation(winsdk.system.Object):
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeviceLockdownProfileInformation: ...

