// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_ApplicationModel_DataTransfer_DragDrop_2_H
#define WINRT_Windows_ApplicationModel_DataTransfer_DragDrop_2_H
#include "winrt/impl/Windows.ApplicationModel.DataTransfer.DragDrop.1.h"
WINRT_EXPORT namespace winrt::Windows::ApplicationModel::DataTransfer::DragDrop
{
}
#endif
