# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.WindowManagement")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

class AppWindowClosedReason(enum.IntEnum):
    OTHER = 0
    APP_INITIATED = 1
    USER_INITIATED = 2

class AppWindowFrameStyle(enum.IntEnum):
    DEFAULT = 0
    NO_FRAME = 1

class AppWindowPresentationKind(enum.IntEnum):
    DEFAULT = 0
    COMPACT_OVERLAY = 1
    FULL_SCREEN = 2

class AppWindowTitleBarVisibility(enum.IntEnum):
    DEFAULT = 0
    ALWAYS_HIDDEN = 1

class WindowingEnvironmentKind(enum.IntEnum):
    UNKNOWN = 0
    OVERLAPPED = 1
    TILED = 2

_ns_module._register_AppWindowClosedReason(AppWindowClosedReason)
_ns_module._register_AppWindowFrameStyle(AppWindowFrameStyle)
_ns_module._register_AppWindowPresentationKind(AppWindowPresentationKind)
_ns_module._register_AppWindowTitleBarVisibility(AppWindowTitleBarVisibility)
_ns_module._register_WindowingEnvironmentKind(WindowingEnvironmentKind)

AppWindow = _ns_module.AppWindow
AppWindowChangedEventArgs = _ns_module.AppWindowChangedEventArgs
AppWindowCloseRequestedEventArgs = _ns_module.AppWindowCloseRequestedEventArgs
AppWindowClosedEventArgs = _ns_module.AppWindowClosedEventArgs
AppWindowFrame = _ns_module.AppWindowFrame
AppWindowPlacement = _ns_module.AppWindowPlacement
AppWindowPresentationConfiguration = _ns_module.AppWindowPresentationConfiguration
AppWindowPresenter = _ns_module.AppWindowPresenter
AppWindowTitleBar = _ns_module.AppWindowTitleBar
AppWindowTitleBarOcclusion = _ns_module.AppWindowTitleBarOcclusion
CompactOverlayPresentationConfiguration = _ns_module.CompactOverlayPresentationConfiguration
DefaultPresentationConfiguration = _ns_module.DefaultPresentationConfiguration
DisplayRegion = _ns_module.DisplayRegion
FullScreenPresentationConfiguration = _ns_module.FullScreenPresentationConfiguration
WindowServices = _ns_module.WindowServices
WindowingEnvironment = _ns_module.WindowingEnvironment
WindowingEnvironmentAddedEventArgs = _ns_module.WindowingEnvironmentAddedEventArgs
WindowingEnvironmentChangedEventArgs = _ns_module.WindowingEnvironmentChangedEventArgs
WindowingEnvironmentRemovedEventArgs = _ns_module.WindowingEnvironmentRemovedEventArgs
