# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Spi.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class ProviderSpiMode(enum.IntEnum):
    MODE0 = 0
    MODE1 = 1
    MODE2 = 2
    MODE3 = 3

class ProviderSpiSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED = 1

_ns_module._register_ProviderSpiMode(ProviderSpiMode)
_ns_module._register_ProviderSpiSharingMode(ProviderSpiSharingMode)

ProviderSpiConnectionSettings = _ns_module.ProviderSpiConnectionSettings
ISpiControllerProvider = _ns_module.ISpiControllerProvider
ISpiDeviceProvider = _ns_module.ISpiDeviceProvider
ISpiProvider = _ns_module.ISpiProvider
