// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_UI_WebUI_Core_1_H
#define WINRT_Windows_UI_WebUI_Core_1_H
#include "winrt/impl/Windows.UI.WebUI.Core.0.h"
WINRT_EXPORT namespace winrt::Windows::UI::WebUI::Core
{
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBar :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBar>
    {
        IWebUICommandBar(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBar(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarBitmapIcon :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarBitmapIcon>,
        impl::require<winrt::Windows::UI::WebUI::Core::IWebUICommandBarBitmapIcon, winrt::Windows::UI::WebUI::Core::IWebUICommandBarIcon>
    {
        IWebUICommandBarBitmapIcon(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarBitmapIcon(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarBitmapIconFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarBitmapIconFactory>
    {
        IWebUICommandBarBitmapIconFactory(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarBitmapIconFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarConfirmationButton :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarConfirmationButton>,
        impl::require<winrt::Windows::UI::WebUI::Core::IWebUICommandBarConfirmationButton, winrt::Windows::UI::WebUI::Core::IWebUICommandBarElement>
    {
        IWebUICommandBarConfirmationButton(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarConfirmationButton(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarElement :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarElement>
    {
        IWebUICommandBarElement(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarElement(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarIcon :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarIcon>
    {
        IWebUICommandBarIcon(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarIcon(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarIconButton :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarIconButton>,
        impl::require<winrt::Windows::UI::WebUI::Core::IWebUICommandBarIconButton, winrt::Windows::UI::WebUI::Core::IWebUICommandBarElement>
    {
        IWebUICommandBarIconButton(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarIconButton(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarItemInvokedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarItemInvokedEventArgs>
    {
        IWebUICommandBarItemInvokedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarItemInvokedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarSizeChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarSizeChangedEventArgs>
    {
        IWebUICommandBarSizeChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarSizeChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarStatics>
    {
        IWebUICommandBarStatics(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarSymbolIcon :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarSymbolIcon>,
        impl::require<winrt::Windows::UI::WebUI::Core::IWebUICommandBarSymbolIcon, winrt::Windows::UI::WebUI::Core::IWebUICommandBarIcon>
    {
        IWebUICommandBarSymbolIcon(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarSymbolIcon(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebUICommandBarSymbolIconFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebUICommandBarSymbolIconFactory>
    {
        IWebUICommandBarSymbolIconFactory(std::nullptr_t = nullptr) noexcept {}
        IWebUICommandBarSymbolIconFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
