# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.DataTransfer.ShareTarget")

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.datatransfer
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


QuickLink = _ns_module.QuickLink
ShareOperation = _ns_module.ShareOperation
