# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system

class DragDropModifiers(enum.IntFlag):
    NONE = 0
    SHIFT = 0x1
    CONTROL = 0x2
    ALT = 0x4
    LEFT_BUTTON = 0x8
    MIDDLE_BUTTON = 0x10
    RIGHT_BUTTON = 0x20

Self = typing.TypeVar('Self')

