# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage
import winsdk.windows.storage.streams

class HidCollectionType(enum.IntEnum):
    PHYSICAL = 0
    APPLICATION = 1
    LOGICAL = 2
    REPORT = 3
    NAMED_ARRAY = 4
    USAGE_SWITCH = 5
    USAGE_MODIFIER = 6
    OTHER = 7

class HidReportType(enum.IntEnum):
    INPUT = 0
    OUTPUT = 1
    FEATURE = 2

Self = typing.TypeVar('Self')

class HidBooleanControl(winsdk.system.Object):
    is_active: winsdk.system.Boolean
    control_description: typing.Optional[HidBooleanControlDescription]
    id: winsdk.system.UInt32
    usage_id: winsdk.system.UInt16
    usage_page: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidBooleanControl: ...

class HidBooleanControlDescription(winsdk.system.Object):
    id: winsdk.system.UInt32
    parent_collections: typing.Optional[winsdk.windows.foundation.collections.IVectorView[HidCollection]]
    report_id: winsdk.system.UInt16
    report_type: HidReportType
    usage_id: winsdk.system.UInt16
    usage_page: winsdk.system.UInt16
    is_absolute: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidBooleanControlDescription: ...

class HidCollection(winsdk.system.Object):
    id: winsdk.system.UInt32
    type: HidCollectionType
    usage_id: winsdk.system.UInt32
    usage_page: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidCollection: ...

class HidDevice(winsdk.system.Object):
    product_id: winsdk.system.UInt16
    usage_id: winsdk.system.UInt16
    usage_page: winsdk.system.UInt16
    vendor_id: winsdk.system.UInt16
    version: winsdk.system.UInt16
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidDevice: ...
    def close(self) -> None: ...
    @typing.overload
    def create_feature_report(self) -> typing.Optional[HidFeatureReport]: ...
    @typing.overload
    def create_feature_report(self, report_id: winsdk.system.UInt16) -> typing.Optional[HidFeatureReport]: ...
    @typing.overload
    def create_output_report(self) -> typing.Optional[HidOutputReport]: ...
    @typing.overload
    def create_output_report(self, report_id: winsdk.system.UInt16) -> typing.Optional[HidOutputReport]: ...
    @staticmethod
    def from_id_async(device_id: str, access_mode: winsdk.windows.storage.FileAccessMode) -> winsdk.windows.foundation.IAsyncOperation[HidDevice]: ...
    def get_boolean_control_descriptions(self, report_type: HidReportType, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[HidBooleanControlDescription]]: ...
    @typing.overload
    @staticmethod
    def get_device_selector(usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> str: ...
    @typing.overload
    @staticmethod
    def get_device_selector(usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16, vendor_id: winsdk.system.UInt16, product_id: winsdk.system.UInt16) -> str: ...
    @typing.overload
    def get_feature_report_async(self) -> winsdk.windows.foundation.IAsyncOperation[HidFeatureReport]: ...
    @typing.overload
    def get_feature_report_async(self, report_id: winsdk.system.UInt16) -> winsdk.windows.foundation.IAsyncOperation[HidFeatureReport]: ...
    @typing.overload
    def get_input_report_async(self) -> winsdk.windows.foundation.IAsyncOperation[HidInputReport]: ...
    @typing.overload
    def get_input_report_async(self, report_id: winsdk.system.UInt16) -> winsdk.windows.foundation.IAsyncOperation[HidInputReport]: ...
    def get_numeric_control_descriptions(self, report_type: HidReportType, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[HidNumericControlDescription]]: ...
    def send_feature_report_async(self, feature_report: typing.Optional[HidFeatureReport]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.UInt32]: ...
    def send_output_report_async(self, output_report: typing.Optional[HidOutputReport]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.UInt32]: ...
    def add_input_report_received(self, report_handler: winsdk.windows.foundation.TypedEventHandler[HidDevice, HidInputReportReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_input_report_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class HidFeatureReport(winsdk.system.Object):
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    id: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidFeatureReport: ...
    def get_boolean_control(self, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[HidBooleanControl]: ...
    def get_boolean_control_by_description(self, control_description: typing.Optional[HidBooleanControlDescription]) -> typing.Optional[HidBooleanControl]: ...
    def get_numeric_control(self, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[HidNumericControl]: ...
    def get_numeric_control_by_description(self, control_description: typing.Optional[HidNumericControlDescription]) -> typing.Optional[HidNumericControl]: ...

class HidInputReport(winsdk.system.Object):
    activated_boolean_controls: typing.Optional[winsdk.windows.foundation.collections.IVectorView[HidBooleanControl]]
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    id: winsdk.system.UInt16
    transitioned_boolean_controls: typing.Optional[winsdk.windows.foundation.collections.IVectorView[HidBooleanControl]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidInputReport: ...
    def get_boolean_control(self, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[HidBooleanControl]: ...
    def get_boolean_control_by_description(self, control_description: typing.Optional[HidBooleanControlDescription]) -> typing.Optional[HidBooleanControl]: ...
    def get_numeric_control(self, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[HidNumericControl]: ...
    def get_numeric_control_by_description(self, control_description: typing.Optional[HidNumericControlDescription]) -> typing.Optional[HidNumericControl]: ...

class HidInputReportReceivedEventArgs(winsdk.system.Object):
    report: typing.Optional[HidInputReport]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidInputReportReceivedEventArgs: ...

class HidNumericControl(winsdk.system.Object):
    value: winsdk.system.Int64
    scaled_value: winsdk.system.Int64
    control_description: typing.Optional[HidNumericControlDescription]
    id: winsdk.system.UInt32
    is_grouped: winsdk.system.Boolean
    usage_id: winsdk.system.UInt16
    usage_page: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidNumericControl: ...

class HidNumericControlDescription(winsdk.system.Object):
    has_null: winsdk.system.Boolean
    id: winsdk.system.UInt32
    is_absolute: winsdk.system.Boolean
    logical_maximum: winsdk.system.Int32
    logical_minimum: winsdk.system.Int32
    parent_collections: typing.Optional[winsdk.windows.foundation.collections.IVectorView[HidCollection]]
    physical_maximum: winsdk.system.Int32
    physical_minimum: winsdk.system.Int32
    report_count: winsdk.system.UInt32
    report_id: winsdk.system.UInt16
    report_size: winsdk.system.UInt32
    report_type: HidReportType
    unit: winsdk.system.UInt32
    unit_exponent: winsdk.system.UInt32
    usage_id: winsdk.system.UInt16
    usage_page: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidNumericControlDescription: ...

class HidOutputReport(winsdk.system.Object):
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    id: winsdk.system.UInt16
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HidOutputReport: ...
    def get_boolean_control(self, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[HidBooleanControl]: ...
    def get_boolean_control_by_description(self, control_description: typing.Optional[HidBooleanControlDescription]) -> typing.Optional[HidBooleanControl]: ...
    def get_numeric_control(self, usage_page: winsdk.system.UInt16, usage_id: winsdk.system.UInt16) -> typing.Optional[HidNumericControl]: ...
    def get_numeric_control_by_description(self, control_description: typing.Optional[HidNumericControlDescription]) -> typing.Optional[HidNumericControl]: ...

