# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Storage.Pickers.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class AddFileResult(enum.IntEnum):
    ADDED = 0
    ALREADY_ADDED = 1
    NOT_ALLOWED = 2
    UNAVAILABLE = 3

class FileSelectionMode(enum.IntEnum):
    SINGLE = 0
    MULTIPLE = 1

class SetFileNameResult(enum.IntEnum):
    SUCCEEDED = 0
    NOT_ALLOWED = 1
    UNAVAILABLE = 2

_ns_module._register_AddFileResult(AddFileResult)
_ns_module._register_FileSelectionMode(FileSelectionMode)
_ns_module._register_SetFileNameResult(SetFileNameResult)

FileOpenPickerUI = _ns_module.FileOpenPickerUI
FileRemovedEventArgs = _ns_module.FileRemovedEventArgs
FileSavePickerUI = _ns_module.FileSavePickerUI
PickerClosingDeferral = _ns_module.PickerClosingDeferral
PickerClosingEventArgs = _ns_module.PickerClosingEventArgs
PickerClosingOperation = _ns_module.PickerClosingOperation
TargetFileRequest = _ns_module.TargetFileRequest
TargetFileRequestDeferral = _ns_module.TargetFileRequestDeferral
TargetFileRequestedEventArgs = _ns_module.TargetFileRequestedEventArgs
