# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Gaming.Preview.GamesEnumeration")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class GameListCategory(enum.IntEnum):
    CANDIDATE = 0
    CONFIRMED_BY_SYSTEM = 1
    CONFIRMED_BY_USER = 2

class GameListEntryLaunchableState(enum.IntEnum):
    NOT_LAUNCHABLE = 0
    BY_LAST_RUNNING_FULL_PATH = 1
    BY_USER_PROVIDED_PATH = 2
    BY_TILE = 3

_ns_module._register_GameListCategory(GameListCategory)
_ns_module._register_GameListEntryLaunchableState(GameListEntryLaunchableState)

GameList = _ns_module.GameList
GameListEntry = _ns_module.GameListEntry
GameModeConfiguration = _ns_module.GameModeConfiguration
GameModeUserConfiguration = _ns_module.GameModeUserConfiguration
IGameListEntry = _ns_module.IGameListEntry
