// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Data.Json.h")
#include "py.Windows.Data.Json.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

#include <winrt/Windows.Data.Json.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.System.h>

#include <winrt/Windows.System.Diagnostics.h>

namespace py::proj::Windows::System::Diagnostics
{}

namespace py::impl::Windows::System::Diagnostics
{}

namespace py::wrapper::Windows::System::Diagnostics
{
    using DiagnosticActionResult = py::winrt_wrapper<winrt::Windows::System::Diagnostics::DiagnosticActionResult>;
    using DiagnosticInvoker = py::winrt_wrapper<winrt::Windows::System::Diagnostics::DiagnosticInvoker>;
    using ProcessCpuUsage = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessCpuUsage>;
    using ProcessCpuUsageReport = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessCpuUsageReport>;
    using ProcessDiagnosticInfo = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessDiagnosticInfo>;
    using ProcessDiskUsage = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessDiskUsage>;
    using ProcessDiskUsageReport = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessDiskUsageReport>;
    using ProcessMemoryUsage = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessMemoryUsage>;
    using ProcessMemoryUsageReport = py::winrt_wrapper<winrt::Windows::System::Diagnostics::ProcessMemoryUsageReport>;
    using SystemCpuUsage = py::winrt_wrapper<winrt::Windows::System::Diagnostics::SystemCpuUsage>;
    using SystemCpuUsageReport = py::winrt_wrapper<winrt::Windows::System::Diagnostics::SystemCpuUsageReport>;
    using SystemDiagnosticInfo = py::winrt_wrapper<winrt::Windows::System::Diagnostics::SystemDiagnosticInfo>;
    using SystemMemoryUsage = py::winrt_wrapper<winrt::Windows::System::Diagnostics::SystemMemoryUsage>;
    using SystemMemoryUsageReport = py::winrt_wrapper<winrt::Windows::System::Diagnostics::SystemMemoryUsageReport>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::DiagnosticActionState> = "i";


    template<>
    struct py_type<winrt::Windows::System::Diagnostics::DiagnosticActionState>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::DiagnosticActionResult>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::DiagnosticInvoker>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessCpuUsage>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessCpuUsageReport>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessDiagnosticInfo>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessDiskUsage>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessDiskUsageReport>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessMemoryUsage>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::ProcessMemoryUsageReport>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::SystemCpuUsage>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::SystemCpuUsageReport>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::SystemDiagnosticInfo>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::SystemMemoryUsage>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::System::Diagnostics::SystemMemoryUsageReport>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
