# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Search")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


LocalContentSuggestionSettings = _ns_module.LocalContentSuggestionSettings
SearchPane = _ns_module.SearchPane
SearchPaneQueryChangedEventArgs = _ns_module.SearchPaneQueryChangedEventArgs
SearchPaneQueryLinguisticDetails = _ns_module.SearchPaneQueryLinguisticDetails
SearchPaneQuerySubmittedEventArgs = _ns_module.SearchPaneQuerySubmittedEventArgs
SearchPaneResultSuggestionChosenEventArgs = _ns_module.SearchPaneResultSuggestionChosenEventArgs
SearchPaneSuggestionsRequest = _ns_module.SearchPaneSuggestionsRequest
SearchPaneSuggestionsRequestDeferral = _ns_module.SearchPaneSuggestionsRequestDeferral
SearchPaneSuggestionsRequestedEventArgs = _ns_module.SearchPaneSuggestionsRequestedEventArgs
SearchPaneVisibilityChangedEventArgs = _ns_module.SearchPaneVisibilityChangedEventArgs
SearchQueryLinguisticDetails = _ns_module.SearchQueryLinguisticDetails
SearchSuggestionCollection = _ns_module.SearchSuggestionCollection
SearchSuggestionsRequest = _ns_module.SearchSuggestionsRequest
SearchSuggestionsRequestDeferral = _ns_module.SearchSuggestionsRequestDeferral
ISearchPaneQueryChangedEventArgs = _ns_module.ISearchPaneQueryChangedEventArgs
