// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"


#include <winrt/Windows.ApplicationModel.DataTransfer.DragDrop.h>

namespace py::proj::Windows::ApplicationModel::DataTransfer::DragDrop
{}

namespace py::impl::Windows::ApplicationModel::DataTransfer::DragDrop
{}

namespace py::wrapper::Windows::ApplicationModel::DataTransfer::DragDrop
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::DataTransfer::DragDrop::DragDropModifiers> = "I";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::DataTransfer::DragDrop::DragDropModifiers>
    {
        static PyObject* get_python_type() noexcept;
    };
}
