// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.System.h>

#include <winrt/Windows.Security.Authentication.OnlineId.h>

namespace py::proj::Windows::Security::Authentication::OnlineId
{}

namespace py::impl::Windows::Security::Authentication::OnlineId
{}

namespace py::wrapper::Windows::Security::Authentication::OnlineId
{
    using OnlineIdAuthenticator = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdAuthenticator>;
    using OnlineIdServiceTicket = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdServiceTicket>;
    using OnlineIdServiceTicketRequest = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdServiceTicketRequest>;
    using OnlineIdSystemAuthenticator = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemAuthenticator>;
    using OnlineIdSystemAuthenticatorForUser = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemAuthenticatorForUser>;
    using OnlineIdSystemIdentity = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemIdentity>;
    using OnlineIdSystemTicketResult = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemTicketResult>;
    using SignOutUserOperation = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::SignOutUserOperation>;
    using UserAuthenticationOperation = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::UserAuthenticationOperation>;
    using UserIdentity = py::winrt_wrapper<winrt::Windows::Security::Authentication::OnlineId::UserIdentity>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Security::Authentication::OnlineId::CredentialPromptType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemTicketStatus> = "i";


    template<>
    struct py_type<winrt::Windows::Security::Authentication::OnlineId::CredentialPromptType>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemTicketStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdAuthenticator>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdServiceTicket>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdServiceTicketRequest>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemAuthenticator>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemAuthenticatorForUser>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemIdentity>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::OnlineIdSystemTicketResult>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::SignOutUserOperation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::UserAuthenticationOperation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Security::Authentication::OnlineId::UserIdentity>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
