# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

Self = typing.TypeVar('Self')

class CommunicationBlockingAccessManager(winsdk.system.Object):
    is_blocking_active: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CommunicationBlockingAccessManager: ...
    @staticmethod
    def is_blocked_number_async(number: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def show_block_numbers_u_i(phone_numbers: typing.Iterable[str]) -> winsdk.system.Boolean: ...
    @staticmethod
    def show_blocked_calls_u_i() -> None: ...
    @staticmethod
    def show_blocked_messages_u_i() -> None: ...
    @staticmethod
    def show_unblock_numbers_u_i(phone_numbers: typing.Iterable[str]) -> winsdk.system.Boolean: ...

class CommunicationBlockingAppManager(winsdk.system.Object):
    is_current_app_active_blocking_app: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CommunicationBlockingAppManager: ...
    @staticmethod
    def request_set_as_active_blocking_app_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def show_communication_blocking_settings_u_i() -> None: ...

