# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Perception.Spatial.Surfaces")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx
except ImportError:
    pass

try:
    import winsdk.windows.perception.spatial
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


SpatialSurfaceInfo = _ns_module.SpatialSurfaceInfo
SpatialSurfaceMesh = _ns_module.SpatialSurfaceMesh
SpatialSurfaceMeshBuffer = _ns_module.SpatialSurfaceMeshBuffer
SpatialSurfaceMeshOptions = _ns_module.SpatialSurfaceMeshOptions
SpatialSurfaceObserver = _ns_module.SpatialSurfaceObserver
