# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.ui

Self = typing.TypeVar('Self')

class ResourceLoader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ResourceLoader: ...
    @typing.overload
    def __new__(cls: typing.Type[ResourceLoader], name: str) -> ResourceLoader:...
    @typing.overload
    def __new__(cls: typing.Type[ResourceLoader]) -> ResourceLoader:...
    @staticmethod
    def get_default_pri_path(package_full_name: str) -> str: ...
    @typing.overload
    @staticmethod
    def get_for_current_view() -> typing.Optional[ResourceLoader]: ...
    @typing.overload
    @staticmethod
    def get_for_current_view(name: str) -> typing.Optional[ResourceLoader]: ...
    @staticmethod
    def get_for_u_i_context(context: typing.Optional[winsdk.windows.ui.UIContext]) -> typing.Optional[ResourceLoader]: ...
    @typing.overload
    @staticmethod
    def get_for_view_independent_use() -> typing.Optional[ResourceLoader]: ...
    @typing.overload
    @staticmethod
    def get_for_view_independent_use(name: str) -> typing.Optional[ResourceLoader]: ...
    def get_string(self, resource: str) -> str: ...
    @staticmethod
    def get_string_for_reference(uri: typing.Optional[winsdk.windows.foundation.Uri]) -> str: ...
    def get_string_for_uri(self, uri: typing.Optional[winsdk.windows.foundation.Uri]) -> str: ...

