// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Phone_Speech_Recognition_H
#define WINRT_Windows_Phone_Speech_Recognition_H
#include "winrt/base.h"
static_assert(winrt::check_version(CPPWINRT_VERSION, "2.0.230225.1"), "Mismatched C++/WinRT headers.");
#define CPPWINRT_VERSION "2.0.230225.1"
#include "winrt/impl/Windows.Phone.Speech.Recognition.2.h"
namespace winrt::impl
{
}
WINRT_EXPORT namespace winrt::Windows::Phone::Speech::Recognition
{
}
namespace std
{
#ifndef WINRT_LEAN_AND_MEAN
#endif
#ifdef __cpp_lib_format
#endif
}
#endif
