# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class ClassicAppManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ClassicAppManager: ...
    @staticmethod
    def find_installed_app(app_uninstall_key: str) -> typing.Optional[InstalledClassicAppInfo]: ...

class InstalledClassicAppInfo(winsdk.system.Object):
    display_name: str
    display_version: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InstalledClassicAppInfo: ...

