// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Media_Capture_1_H
#define WINRT_Windows_Media_Capture_1_H
#include "winrt/impl/Windows.Foundation.0.h"
#include "winrt/impl/Windows.Storage.Streams.0.h"
#include "winrt/impl/Windows.Media.Capture.0.h"
WINRT_EXPORT namespace winrt::Windows::Media::Capture
{
    struct WINRT_IMPL_EMPTY_BASES IAdvancedCapturedPhoto :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAdvancedCapturedPhoto>
    {
        IAdvancedCapturedPhoto(std::nullptr_t = nullptr) noexcept {}
        IAdvancedCapturedPhoto(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAdvancedCapturedPhoto2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAdvancedCapturedPhoto2>
    {
        IAdvancedCapturedPhoto2(std::nullptr_t = nullptr) noexcept {}
        IAdvancedCapturedPhoto2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAdvancedPhotoCapture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAdvancedPhotoCapture>
    {
        IAdvancedPhotoCapture(std::nullptr_t = nullptr) noexcept {}
        IAdvancedPhotoCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastBackgroundService :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastBackgroundService>
    {
        IAppBroadcastBackgroundService(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastBackgroundService(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastBackgroundService2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastBackgroundService2>
    {
        IAppBroadcastBackgroundService2(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastBackgroundService2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastBackgroundServiceSignInInfo :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastBackgroundServiceSignInInfo>
    {
        IAppBroadcastBackgroundServiceSignInInfo(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastBackgroundServiceSignInInfo(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastBackgroundServiceSignInInfo2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastBackgroundServiceSignInInfo2>
    {
        IAppBroadcastBackgroundServiceSignInInfo2(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastBackgroundServiceSignInInfo2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastBackgroundServiceStreamInfo :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastBackgroundServiceStreamInfo>
    {
        IAppBroadcastBackgroundServiceStreamInfo(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastBackgroundServiceStreamInfo(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastBackgroundServiceStreamInfo2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastBackgroundServiceStreamInfo2>
    {
        IAppBroadcastBackgroundServiceStreamInfo2(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastBackgroundServiceStreamInfo2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastCameraCaptureStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastCameraCaptureStateChangedEventArgs>
    {
        IAppBroadcastCameraCaptureStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastCameraCaptureStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastGlobalSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastGlobalSettings>
    {
        IAppBroadcastGlobalSettings(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastGlobalSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastHeartbeatRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastHeartbeatRequestedEventArgs>
    {
        IAppBroadcastHeartbeatRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastHeartbeatRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastManagerStatics>
    {
        IAppBroadcastManagerStatics(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastMicrophoneCaptureStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastMicrophoneCaptureStateChangedEventArgs>
    {
        IAppBroadcastMicrophoneCaptureStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastMicrophoneCaptureStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPlugIn :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPlugIn>
    {
        IAppBroadcastPlugIn(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPlugIn(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPlugInManager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPlugInManager>
    {
        IAppBroadcastPlugInManager(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPlugInManager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPlugInManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPlugInManagerStatics>
    {
        IAppBroadcastPlugInManagerStatics(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPlugInManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPlugInStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPlugInStateChangedEventArgs>
    {
        IAppBroadcastPlugInStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPlugInStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPreview :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPreview>
    {
        IAppBroadcastPreview(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPreview(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPreviewStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPreviewStateChangedEventArgs>
    {
        IAppBroadcastPreviewStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPreviewStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPreviewStreamReader :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPreviewStreamReader>
    {
        IAppBroadcastPreviewStreamReader(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPreviewStreamReader(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPreviewStreamVideoFrame :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPreviewStreamVideoFrame>
    {
        IAppBroadcastPreviewStreamVideoFrame(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPreviewStreamVideoFrame(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastPreviewStreamVideoHeader :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastPreviewStreamVideoHeader>
    {
        IAppBroadcastPreviewStreamVideoHeader(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastPreviewStreamVideoHeader(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastProviderSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastProviderSettings>
    {
        IAppBroadcastProviderSettings(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastProviderSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastServices :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastServices>
    {
        IAppBroadcastServices(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastServices(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastSignInStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastSignInStateChangedEventArgs>
    {
        IAppBroadcastSignInStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastSignInStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastState :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastState>
    {
        IAppBroadcastState(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastState(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastStreamAudioFrame :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastStreamAudioFrame>
    {
        IAppBroadcastStreamAudioFrame(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastStreamAudioFrame(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastStreamAudioHeader :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastStreamAudioHeader>
    {
        IAppBroadcastStreamAudioHeader(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastStreamAudioHeader(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastStreamReader :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastStreamReader>
    {
        IAppBroadcastStreamReader(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastStreamReader(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastStreamStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastStreamStateChangedEventArgs>
    {
        IAppBroadcastStreamStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastStreamStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastStreamVideoFrame :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastStreamVideoFrame>
    {
        IAppBroadcastStreamVideoFrame(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastStreamVideoFrame(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastStreamVideoHeader :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastStreamVideoHeader>
    {
        IAppBroadcastStreamVideoHeader(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastStreamVideoHeader(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastTriggerDetails :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastTriggerDetails>
    {
        IAppBroadcastTriggerDetails(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastTriggerDetails(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppBroadcastViewerCountChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppBroadcastViewerCountChangedEventArgs>
    {
        IAppBroadcastViewerCountChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppBroadcastViewerCountChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCapture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCapture>
    {
        IAppCapture(std::nullptr_t = nullptr) noexcept {}
        IAppCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureAlternateShortcutKeys :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureAlternateShortcutKeys>
    {
        IAppCaptureAlternateShortcutKeys(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureAlternateShortcutKeys(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureAlternateShortcutKeys2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureAlternateShortcutKeys2>
    {
        IAppCaptureAlternateShortcutKeys2(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureAlternateShortcutKeys2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureAlternateShortcutKeys3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureAlternateShortcutKeys3>
    {
        IAppCaptureAlternateShortcutKeys3(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureAlternateShortcutKeys3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureDurationGeneratedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureDurationGeneratedEventArgs>
    {
        IAppCaptureDurationGeneratedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureDurationGeneratedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureFileGeneratedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureFileGeneratedEventArgs>
    {
        IAppCaptureFileGeneratedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureFileGeneratedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureManagerStatics>
    {
        IAppCaptureManagerStatics(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureMetadataWriter :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureMetadataWriter>
    {
        IAppCaptureMetadataWriter(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureMetadataWriter(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureMicrophoneCaptureStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureMicrophoneCaptureStateChangedEventArgs>
    {
        IAppCaptureMicrophoneCaptureStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureMicrophoneCaptureStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureRecordOperation :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureRecordOperation>
    {
        IAppCaptureRecordOperation(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureRecordOperation(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureRecordingStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureRecordingStateChangedEventArgs>
    {
        IAppCaptureRecordingStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureRecordingStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureServices :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureServices>
    {
        IAppCaptureServices(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureServices(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureSettings>
    {
        IAppCaptureSettings(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureSettings2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureSettings2>
    {
        IAppCaptureSettings2(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureSettings2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureSettings3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureSettings3>
    {
        IAppCaptureSettings3(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureSettings3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureSettings4 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureSettings4>
    {
        IAppCaptureSettings4(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureSettings4(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureSettings5 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureSettings5>
    {
        IAppCaptureSettings5(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureSettings5(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureState :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureState>
    {
        IAppCaptureState(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureState(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureStatics>
    {
        IAppCaptureStatics(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppCaptureStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppCaptureStatics2>
    {
        IAppCaptureStatics2(std::nullptr_t = nullptr) noexcept {}
        IAppCaptureStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICameraCaptureUI :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICameraCaptureUI>
    {
        ICameraCaptureUI(std::nullptr_t = nullptr) noexcept {}
        ICameraCaptureUI(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICameraCaptureUIPhotoCaptureSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICameraCaptureUIPhotoCaptureSettings>
    {
        ICameraCaptureUIPhotoCaptureSettings(std::nullptr_t = nullptr) noexcept {}
        ICameraCaptureUIPhotoCaptureSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICameraCaptureUIVideoCaptureSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICameraCaptureUIVideoCaptureSettings>
    {
        ICameraCaptureUIVideoCaptureSettings(std::nullptr_t = nullptr) noexcept {}
        ICameraCaptureUIVideoCaptureSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICameraOptionsUIStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICameraOptionsUIStatics>
    {
        ICameraOptionsUIStatics(std::nullptr_t = nullptr) noexcept {}
        ICameraOptionsUIStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICapturedFrame :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICapturedFrame>,
        impl::require<winrt::Windows::Media::Capture::ICapturedFrame, winrt::Windows::Foundation::IClosable, winrt::Windows::Storage::Streams::IInputStream, winrt::Windows::Storage::Streams::IOutputStream, winrt::Windows::Storage::Streams::IRandomAccessStream, winrt::Windows::Storage::Streams::IContentTypeProvider, winrt::Windows::Storage::Streams::IRandomAccessStreamWithContentType>
    {
        ICapturedFrame(std::nullptr_t = nullptr) noexcept {}
        ICapturedFrame(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICapturedFrame2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICapturedFrame2>
    {
        ICapturedFrame2(std::nullptr_t = nullptr) noexcept {}
        ICapturedFrame2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICapturedFrameControlValues :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICapturedFrameControlValues>
    {
        ICapturedFrameControlValues(std::nullptr_t = nullptr) noexcept {}
        ICapturedFrameControlValues(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICapturedFrameControlValues2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICapturedFrameControlValues2>
    {
        ICapturedFrameControlValues2(std::nullptr_t = nullptr) noexcept {}
        ICapturedFrameControlValues2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICapturedFrameWithSoftwareBitmap :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICapturedFrameWithSoftwareBitmap>
    {
        ICapturedFrameWithSoftwareBitmap(std::nullptr_t = nullptr) noexcept {}
        ICapturedFrameWithSoftwareBitmap(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICapturedPhoto :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICapturedPhoto>
    {
        ICapturedPhoto(std::nullptr_t = nullptr) noexcept {}
        ICapturedPhoto(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameBarServices :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameBarServices>
    {
        IGameBarServices(std::nullptr_t = nullptr) noexcept {}
        IGameBarServices(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameBarServicesCommandEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameBarServicesCommandEventArgs>
    {
        IGameBarServicesCommandEventArgs(std::nullptr_t = nullptr) noexcept {}
        IGameBarServicesCommandEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameBarServicesManager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameBarServicesManager>
    {
        IGameBarServicesManager(std::nullptr_t = nullptr) noexcept {}
        IGameBarServicesManager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameBarServicesManagerGameBarServicesCreatedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameBarServicesManagerGameBarServicesCreatedEventArgs>
    {
        IGameBarServicesManagerGameBarServicesCreatedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IGameBarServicesManagerGameBarServicesCreatedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameBarServicesManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameBarServicesManagerStatics>
    {
        IGameBarServicesManagerStatics(std::nullptr_t = nullptr) noexcept {}
        IGameBarServicesManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameBarServicesTargetInfo :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameBarServicesTargetInfo>
    {
        IGameBarServicesTargetInfo(std::nullptr_t = nullptr) noexcept {}
        IGameBarServicesTargetInfo(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILowLagMediaRecording :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILowLagMediaRecording>
    {
        ILowLagMediaRecording(std::nullptr_t = nullptr) noexcept {}
        ILowLagMediaRecording(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILowLagMediaRecording2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILowLagMediaRecording2>
    {
        ILowLagMediaRecording2(std::nullptr_t = nullptr) noexcept {}
        ILowLagMediaRecording2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILowLagMediaRecording3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILowLagMediaRecording3>
    {
        ILowLagMediaRecording3(std::nullptr_t = nullptr) noexcept {}
        ILowLagMediaRecording3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILowLagPhotoCapture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILowLagPhotoCapture>
    {
        ILowLagPhotoCapture(std::nullptr_t = nullptr) noexcept {}
        ILowLagPhotoCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILowLagPhotoSequenceCapture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILowLagPhotoSequenceCapture>
    {
        ILowLagPhotoSequenceCapture(std::nullptr_t = nullptr) noexcept {}
        ILowLagPhotoSequenceCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture>
    {
        IMediaCapture(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture2>
    {
        IMediaCapture2(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture3>
    {
        IMediaCapture3(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture4 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture4>
    {
        IMediaCapture4(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture4(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture5 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture5>
    {
        IMediaCapture5(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture5(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture6 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture6>
    {
        IMediaCapture6(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture6(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapture7 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapture7>
    {
        IMediaCapture7(std::nullptr_t = nullptr) noexcept {}
        IMediaCapture7(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureDeviceExclusiveControlStatusChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureDeviceExclusiveControlStatusChangedEventArgs>
    {
        IMediaCaptureDeviceExclusiveControlStatusChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureDeviceExclusiveControlStatusChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureFailedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureFailedEventArgs>
    {
        IMediaCaptureFailedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureFailedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureFocusChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureFocusChangedEventArgs>
    {
        IMediaCaptureFocusChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureFocusChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings>
    {
        IMediaCaptureInitializationSettings(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings2>
    {
        IMediaCaptureInitializationSettings2(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings3>
    {
        IMediaCaptureInitializationSettings3(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings4 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings4>
    {
        IMediaCaptureInitializationSettings4(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings4(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings5 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings5>
    {
        IMediaCaptureInitializationSettings5(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings5(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings6 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings6>
    {
        IMediaCaptureInitializationSettings6(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings6(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureInitializationSettings7 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureInitializationSettings7>
    {
        IMediaCaptureInitializationSettings7(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureInitializationSettings7(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCapturePauseResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCapturePauseResult>
    {
        IMediaCapturePauseResult(std::nullptr_t = nullptr) noexcept {}
        IMediaCapturePauseResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureRelativePanelWatcher :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureRelativePanelWatcher>
    {
        IMediaCaptureRelativePanelWatcher(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureRelativePanelWatcher(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureSettings>
    {
        IMediaCaptureSettings(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureSettings2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureSettings2>
    {
        IMediaCaptureSettings2(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureSettings2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureSettings3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureSettings3>
    {
        IMediaCaptureSettings3(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureSettings3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureStatics>
    {
        IMediaCaptureStatics(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureStopResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureStopResult>
    {
        IMediaCaptureStopResult(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureStopResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureVideoPreview :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureVideoPreview>
    {
        IMediaCaptureVideoPreview(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureVideoPreview(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureVideoProfile :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureVideoProfile>
    {
        IMediaCaptureVideoProfile(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureVideoProfile(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureVideoProfile2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureVideoProfile2>
    {
        IMediaCaptureVideoProfile2(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureVideoProfile2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureVideoProfileMediaDescription :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureVideoProfileMediaDescription>
    {
        IMediaCaptureVideoProfileMediaDescription(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureVideoProfileMediaDescription(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMediaCaptureVideoProfileMediaDescription2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMediaCaptureVideoProfileMediaDescription2>
    {
        IMediaCaptureVideoProfileMediaDescription2(std::nullptr_t = nullptr) noexcept {}
        IMediaCaptureVideoProfileMediaDescription2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IOptionalReferencePhotoCapturedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IOptionalReferencePhotoCapturedEventArgs>
    {
        IOptionalReferencePhotoCapturedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IOptionalReferencePhotoCapturedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPhotoCapturedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPhotoCapturedEventArgs>
    {
        IPhotoCapturedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPhotoCapturedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPhotoConfirmationCapturedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPhotoConfirmationCapturedEventArgs>
    {
        IPhotoConfirmationCapturedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPhotoConfirmationCapturedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IScreenCapture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IScreenCapture>
    {
        IScreenCapture(std::nullptr_t = nullptr) noexcept {}
        IScreenCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IScreenCaptureStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IScreenCaptureStatics>
    {
        IScreenCaptureStatics(std::nullptr_t = nullptr) noexcept {}
        IScreenCaptureStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISourceSuspensionChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISourceSuspensionChangedEventArgs>
    {
        ISourceSuspensionChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ISourceSuspensionChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVideoStreamConfiguration :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVideoStreamConfiguration>
    {
        IVideoStreamConfiguration(std::nullptr_t = nullptr) noexcept {}
        IVideoStreamConfiguration(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
