// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Phone_System_UserProfile_GameServices_Core_1_H
#define WINRT_Windows_Phone_System_UserProfile_GameServices_Core_1_H
#include "winrt/impl/Windows.Phone.System.UserProfile.GameServices.Core.0.h"
WINRT_EXPORT namespace winrt::Windows::Phone::System::UserProfile::GameServices::Core
{
    struct WINRT_IMPL_EMPTY_BASES IGameService :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameService>
    {
        IGameService(std::nullptr_t = nullptr) noexcept {}
        IGameService(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameService2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameService2>
    {
        IGameService2(std::nullptr_t = nullptr) noexcept {}
        IGameService2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IGameServicePropertyCollection :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IGameServicePropertyCollection>
    {
        IGameServicePropertyCollection(std::nullptr_t = nullptr) noexcept {}
        IGameServicePropertyCollection(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
