// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Devices_Printers_Extensions_1_H
#define WINRT_Windows_Devices_Printers_Extensions_1_H
#include "winrt/impl/Windows.Devices.Printers.Extensions.0.h"
WINRT_EXPORT namespace winrt::Windows::Devices::Printers::Extensions
{
    struct WINRT_IMPL_EMPTY_BASES IPrint3DWorkflow :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrint3DWorkflow>
    {
        IPrint3DWorkflow(std::nullptr_t = nullptr) noexcept {}
        IPrint3DWorkflow(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrint3DWorkflow2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrint3DWorkflow2>
    {
        IPrint3DWorkflow2(std::nullptr_t = nullptr) noexcept {}
        IPrint3DWorkflow2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrint3DWorkflowPrintRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrint3DWorkflowPrintRequestedEventArgs>
    {
        IPrint3DWorkflowPrintRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPrint3DWorkflowPrintRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrint3DWorkflowPrinterChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrint3DWorkflowPrinterChangedEventArgs>
    {
        IPrint3DWorkflowPrinterChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPrint3DWorkflowPrinterChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrintExtensionContextStatic :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrintExtensionContextStatic>
    {
        IPrintExtensionContextStatic(std::nullptr_t = nullptr) noexcept {}
        IPrintExtensionContextStatic(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrintNotificationEventDetails :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrintNotificationEventDetails>
    {
        IPrintNotificationEventDetails(std::nullptr_t = nullptr) noexcept {}
        IPrintNotificationEventDetails(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrintTaskConfiguration :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrintTaskConfiguration>
    {
        IPrintTaskConfiguration(std::nullptr_t = nullptr) noexcept {}
        IPrintTaskConfiguration(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrintTaskConfigurationSaveRequest :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrintTaskConfigurationSaveRequest>
    {
        IPrintTaskConfigurationSaveRequest(std::nullptr_t = nullptr) noexcept {}
        IPrintTaskConfigurationSaveRequest(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrintTaskConfigurationSaveRequestedDeferral :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrintTaskConfigurationSaveRequestedDeferral>
    {
        IPrintTaskConfigurationSaveRequestedDeferral(std::nullptr_t = nullptr) noexcept {}
        IPrintTaskConfigurationSaveRequestedDeferral(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPrintTaskConfigurationSaveRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPrintTaskConfigurationSaveRequestedEventArgs>
    {
        IPrintTaskConfigurationSaveRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPrintTaskConfigurationSaveRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
