# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Storage.AccessCache")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class AccessCacheOptions(enum.IntFlag):
    NONE = 0
    DISALLOW_USER_INPUT = 0x1
    FAST_LOCATIONS_ONLY = 0x2
    USE_READ_ONLY_CACHED_COPY = 0x4
    SUPPRESS_ACCESS_TIME_UPDATE = 0x8

class RecentStorageItemVisibility(enum.IntEnum):
    APP_ONLY = 0
    APP_AND_SYSTEM = 1

_ns_module._register_AccessCacheOptions(AccessCacheOptions)
_ns_module._register_RecentStorageItemVisibility(RecentStorageItemVisibility)

AccessListEntry = _ns_module.AccessListEntry
AccessListEntryView = _ns_module.AccessListEntryView
ItemRemovedEventArgs = _ns_module.ItemRemovedEventArgs
StorageApplicationPermissions = _ns_module.StorageApplicationPermissions
StorageItemAccessList = _ns_module.StorageItemAccessList
StorageItemMostRecentlyUsedList = _ns_module.StorageItemMostRecentlyUsedList
IStorageItemAccessList = _ns_module.IStorageItemAccessList
