# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.UserDataTasks.DataProvider")

try:
    import winsdk.windows.applicationmodel.userdatatasks
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass


UserDataTaskDataProviderConnection = _ns_module.UserDataTaskDataProviderConnection
UserDataTaskDataProviderTriggerDetails = _ns_module.UserDataTaskDataProviderTriggerDetails
UserDataTaskListCompleteTaskRequest = _ns_module.UserDataTaskListCompleteTaskRequest
UserDataTaskListCompleteTaskRequestEventArgs = _ns_module.UserDataTaskListCompleteTaskRequestEventArgs
UserDataTaskListCreateOrUpdateTaskRequest = _ns_module.UserDataTaskListCreateOrUpdateTaskRequest
UserDataTaskListCreateOrUpdateTaskRequestEventArgs = _ns_module.UserDataTaskListCreateOrUpdateTaskRequestEventArgs
UserDataTaskListDeleteTaskRequest = _ns_module.UserDataTaskListDeleteTaskRequest
UserDataTaskListDeleteTaskRequestEventArgs = _ns_module.UserDataTaskListDeleteTaskRequestEventArgs
UserDataTaskListSkipOccurrenceRequest = _ns_module.UserDataTaskListSkipOccurrenceRequest
UserDataTaskListSkipOccurrenceRequestEventArgs = _ns_module.UserDataTaskListSkipOccurrenceRequestEventArgs
UserDataTaskListSyncManagerSyncRequest = _ns_module.UserDataTaskListSyncManagerSyncRequest
UserDataTaskListSyncManagerSyncRequestEventArgs = _ns_module.UserDataTaskListSyncManagerSyncRequestEventArgs
