# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

Self = typing.TypeVar('Self')

class EnterpriseKeyCredentialRegistrationInfo(winsdk.system.Object):
    key_id: str
    key_name: str
    subject: str
    tenant_id: str
    tenant_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnterpriseKeyCredentialRegistrationInfo: ...

class EnterpriseKeyCredentialRegistrationManager(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[EnterpriseKeyCredentialRegistrationManager]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnterpriseKeyCredentialRegistrationManager: ...
    def get_registrations_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EnterpriseKeyCredentialRegistrationInfo]]: ...

