# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Core.Preview.Communications")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class PreviewMeetingInfoDisplayKind(enum.IntEnum):
    ORGANIZER_AND_TIME = 0
    ORGANIZER_TIME_AND_TITLE = 1

class PreviewSystemState(enum.IntEnum):
    PREPARING = 0
    REBOOTING = 1
    ERROR = 2
    SESSION_PAUSED = 3
    READY = 4

class PreviewTeamEndMeetingKind(enum.IntEnum):
    SHOW_DEFAULT_VIEW = 0
    CLOSE_VIEW = 1

class PreviewTeamViewCommand(enum.IntEnum):
    TOGGLE_CALL_CONTROL = 0
    SHOW_PEOPLE = 1
    SHOW_MESSAGING = 2
    SHOW_CONTENT = 3
    TOGGLE_MICROPHONE = 4
    TOGGLE_CAMERA = 5
    SHOW_CALENDAR = 6
    TOGGLE_SCREEN_SHARING = 7
    TOGGLE_FULL_SCREEN = 8

_ns_module._register_PreviewMeetingInfoDisplayKind(PreviewMeetingInfoDisplayKind)
_ns_module._register_PreviewSystemState(PreviewSystemState)
_ns_module._register_PreviewTeamEndMeetingKind(PreviewTeamEndMeetingKind)
_ns_module._register_PreviewTeamViewCommand(PreviewTeamViewCommand)

PreviewTeamCleanupRequestedEventArgs = _ns_module.PreviewTeamCleanupRequestedEventArgs
PreviewTeamCommandInvokedEventArgs = _ns_module.PreviewTeamCommandInvokedEventArgs
PreviewTeamDeviceCredentials = _ns_module.PreviewTeamDeviceCredentials
PreviewTeamEndMeetingRequestedEventArgs = _ns_module.PreviewTeamEndMeetingRequestedEventArgs
PreviewTeamJoinMeetingRequestedEventArgs = _ns_module.PreviewTeamJoinMeetingRequestedEventArgs
PreviewTeamView = _ns_module.PreviewTeamView
