# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Display")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.graphics
except ImportError:
    pass

class DisplayMonitorConnectionKind(enum.IntEnum):
    INTERNAL = 0
    WIRED = 1
    WIRELESS = 2
    VIRTUAL = 3

class DisplayMonitorDescriptorKind(enum.IntEnum):
    EDID = 0
    DISPLAY_ID = 1

class DisplayMonitorPhysicalConnectorKind(enum.IntEnum):
    UNKNOWN = 0
    H_D15 = 1
    ANALOG_T_V = 2
    DVI = 3
    HDMI = 4
    LVDS = 5
    SDI = 6
    DISPLAY_PORT = 7

class DisplayMonitorUsageKind(enum.IntEnum):
    STANDARD = 0
    HEAD_MOUNTED = 1
    SPECIAL_PURPOSE = 2

_ns_module._register_DisplayMonitorConnectionKind(DisplayMonitorConnectionKind)
_ns_module._register_DisplayMonitorDescriptorKind(DisplayMonitorDescriptorKind)
_ns_module._register_DisplayMonitorPhysicalConnectorKind(DisplayMonitorPhysicalConnectorKind)
_ns_module._register_DisplayMonitorUsageKind(DisplayMonitorUsageKind)

DisplayMonitor = _ns_module.DisplayMonitor
