// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_UI_Core_Preview_Communications_1_H
#define WINRT_Windows_UI_Core_Preview_Communications_1_H
#include "winrt/impl/Windows.UI.Core.Preview.Communications.0.h"
WINRT_EXPORT namespace winrt::Windows::UI::Core::Preview::Communications
{
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamCleanupRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamCleanupRequestedEventArgs>
    {
        IPreviewTeamCleanupRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamCleanupRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamCommandInvokedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamCommandInvokedEventArgs>
    {
        IPreviewTeamCommandInvokedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamCommandInvokedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamDeviceCredentials :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamDeviceCredentials>
    {
        IPreviewTeamDeviceCredentials(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamDeviceCredentials(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamEndMeetingRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamEndMeetingRequestedEventArgs>
    {
        IPreviewTeamEndMeetingRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamEndMeetingRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamJoinMeetingRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamJoinMeetingRequestedEventArgs>
    {
        IPreviewTeamJoinMeetingRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamJoinMeetingRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamView>
    {
        IPreviewTeamView(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamView2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamView2>
    {
        IPreviewTeamView2(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamView2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPreviewTeamViewStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPreviewTeamViewStatics>
    {
        IPreviewTeamViewStatics(std::nullptr_t = nullptr) noexcept {}
        IPreviewTeamViewStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
