// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.System.Power.h")
#include "py.Windows.System.Power.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.System.Power.h>

#include <winrt/Windows.Devices.Power.h>

namespace py::proj::Windows::Devices::Power
{}

namespace py::impl::Windows::Devices::Power
{}

namespace py::wrapper::Windows::Devices::Power
{
    using Battery = py::winrt_wrapper<winrt::Windows::Devices::Power::Battery>;
    using BatteryReport = py::winrt_wrapper<winrt::Windows::Devices::Power::BatteryReport>;
}

namespace py
{

    template<>
    struct winrt_type<winrt::Windows::Devices::Power::Battery>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Power::BatteryReport>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
