# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class AutomationConnection(winsdk.system.Object):
    app_user_model_id: str
    executable_file_name: str
    is_remote_system: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationConnection: ...

class AutomationConnectionBoundObject(winsdk.system.Object):
    connection: typing.Optional[AutomationConnection]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationConnectionBoundObject: ...

class AutomationElement(winsdk.system.Object):
    app_user_model_id: str
    executable_file_name: str
    is_remote_system: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationElement: ...

class AutomationTextRange(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationTextRange: ...

