# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Geolocation.Provider")

try:
    import winsdk.windows.devices.geolocation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class LocationOverrideStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    ALREADY_STARTED = 2
    OTHER = 3

_ns_module._register_LocationOverrideStatus(LocationOverrideStatus)

GeolocationProvider = _ns_module.GeolocationProvider
