# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input.Inking.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

try:
    import winsdk.windows.ui.input.inking
except ImportError:
    pass

class CoreWetStrokeDisposition(enum.IntEnum):
    INKING = 0
    COMPLETED = 1
    CANCELED = 2

_ns_module._register_CoreWetStrokeDisposition(CoreWetStrokeDisposition)

CoreIncrementalInkStroke = _ns_module.CoreIncrementalInkStroke
CoreInkIndependentInputSource = _ns_module.CoreInkIndependentInputSource
CoreInkPresenterHost = _ns_module.CoreInkPresenterHost
CoreWetStrokeUpdateEventArgs = _ns_module.CoreWetStrokeUpdateEventArgs
CoreWetStrokeUpdateSource = _ns_module.CoreWetStrokeUpdateSource
