// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Devices.I2c.Provider.h")
#include "py.Windows.Devices.I2c.Provider.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#include <winrt/Windows.Devices.I2c.Provider.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>

#include <winrt/Windows.Devices.I2c.h>

namespace py::proj::Windows::Devices::I2c
{}

namespace py::impl::Windows::Devices::I2c
{}

namespace py::wrapper::Windows::Devices::I2c
{
    using I2cConnectionSettings = py::winrt_wrapper<winrt::Windows::Devices::I2c::I2cConnectionSettings>;
    using I2cController = py::winrt_wrapper<winrt::Windows::Devices::I2c::I2cController>;
    using I2cDevice = py::winrt_wrapper<winrt::Windows::Devices::I2c::I2cDevice>;
    using II2cDeviceStatics = py::winrt_wrapper<winrt::Windows::Devices::I2c::II2cDeviceStatics>;
    using I2cTransferResult = py::winrt_struct_wrapper<winrt::Windows::Devices::I2c::I2cTransferResult>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::I2c::I2cBusSpeed> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::I2c::I2cSharingMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::I2c::I2cTransferStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Devices::I2c::I2cTransferResult> = "T{i:status:I:bytes_transferred:}";


    template<>
    struct py_type<winrt::Windows::Devices::I2c::I2cBusSpeed>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Devices::I2c::I2cSharingMode>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::Devices::I2c::I2cTransferStatus>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::I2c::I2cConnectionSettings>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::I2c::I2cController>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::I2c::I2cDevice>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::I2c::II2cDeviceStatics>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::I2c::I2cTransferResult>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
    template<>
    struct converter<winrt::Windows::Devices::I2c::I2cTransferResult>
    {
        static PyObject* convert(winrt::Windows::Devices::I2c::I2cTransferResult instance) noexcept;
        static winrt::Windows::Devices::I2c::I2cTransferResult convert_to(PyObject* obj);
    };

}
