// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.230225.1

#pragma once
#ifndef WINRT_Windows_Phone_Management_Deployment_1_H
#define WINRT_Windows_Phone_Management_Deployment_1_H
#include "winrt/impl/Windows.Phone.Management.Deployment.0.h"
WINRT_EXPORT namespace winrt::Windows::Phone::Management::Deployment
{
    struct WINRT_IMPL_EMPTY_BASES IEnterprise :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IEnterprise>
    {
        IEnterprise(std::nullptr_t = nullptr) noexcept {}
        IEnterprise(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IEnterpriseEnrollmentManager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IEnterpriseEnrollmentManager>
    {
        IEnterpriseEnrollmentManager(std::nullptr_t = nullptr) noexcept {}
        IEnterpriseEnrollmentManager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IEnterpriseEnrollmentResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IEnterpriseEnrollmentResult>
    {
        IEnterpriseEnrollmentResult(std::nullptr_t = nullptr) noexcept {}
        IEnterpriseEnrollmentResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInstallationManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInstallationManagerStatics>
    {
        IInstallationManagerStatics(std::nullptr_t = nullptr) noexcept {}
        IInstallationManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInstallationManagerStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInstallationManagerStatics2>
    {
        IInstallationManagerStatics2(std::nullptr_t = nullptr) noexcept {}
        IInstallationManagerStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageInstallResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageInstallResult>
    {
        IPackageInstallResult(std::nullptr_t = nullptr) noexcept {}
        IPackageInstallResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageInstallResult2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageInstallResult2>
    {
        IPackageInstallResult2(std::nullptr_t = nullptr) noexcept {}
        IPackageInstallResult2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
