# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.UserDataAccounts")

try:
    import winsdk.windows.applicationmodel.appointments
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.email
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.userdatatasks
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class UserDataAccountContentKinds(enum.IntFlag):
    EMAIL = 0x1
    CONTACT = 0x2
    APPOINTMENT = 0x4

class UserDataAccountOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    FULL = 1
    NONE = 2

class UserDataAccountStoreAccessType(enum.IntEnum):
    ALL_ACCOUNTS_READ_ONLY = 0
    APP_ACCOUNTS_READ_WRITE = 1

_ns_module._register_UserDataAccountContentKinds(UserDataAccountContentKinds)
_ns_module._register_UserDataAccountOtherAppReadAccess(UserDataAccountOtherAppReadAccess)
_ns_module._register_UserDataAccountStoreAccessType(UserDataAccountStoreAccessType)

UserDataAccount = _ns_module.UserDataAccount
UserDataAccountManager = _ns_module.UserDataAccountManager
UserDataAccountManagerForUser = _ns_module.UserDataAccountManagerForUser
UserDataAccountStore = _ns_module.UserDataAccountStore
UserDataAccountStoreChangedEventArgs = _ns_module.UserDataAccountStoreChangedEventArgs
