// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>

#include <winrt/Windows.UI.Core.AnimationMetrics.h>

namespace py::proj::Windows::UI::Core::AnimationMetrics
{}

namespace py::impl::Windows::UI::Core::AnimationMetrics
{}

namespace py::wrapper::Windows::UI::Core::AnimationMetrics
{
    using AnimationDescription = py::winrt_wrapper<winrt::Windows::UI::Core::AnimationMetrics::AnimationDescription>;
    using OpacityAnimation = py::winrt_wrapper<winrt::Windows::UI::Core::AnimationMetrics::OpacityAnimation>;
    using PropertyAnimation = py::winrt_wrapper<winrt::Windows::UI::Core::AnimationMetrics::PropertyAnimation>;
    using ScaleAnimation = py::winrt_wrapper<winrt::Windows::UI::Core::AnimationMetrics::ScaleAnimation>;
    using TranslationAnimation = py::winrt_wrapper<winrt::Windows::UI::Core::AnimationMetrics::TranslationAnimation>;
    using IPropertyAnimation = py::winrt_wrapper<winrt::Windows::UI::Core::AnimationMetrics::IPropertyAnimation>;
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Core::AnimationMetrics::AnimationEffect> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Core::AnimationMetrics::AnimationEffectTarget> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Core::AnimationMetrics::PropertyAnimationType> = "i";


    template<>
    struct py_type<winrt::Windows::UI::Core::AnimationMetrics::AnimationEffect>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Core::AnimationMetrics::AnimationEffectTarget>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct py_type<winrt::Windows::UI::Core::AnimationMetrics::PropertyAnimationType>
    {
        static PyObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Core::AnimationMetrics::AnimationDescription>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Core::AnimationMetrics::OpacityAnimation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Core::AnimationMetrics::PropertyAnimation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Core::AnimationMetrics::ScaleAnimation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Core::AnimationMetrics::TranslationAnimation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };

    template<>
    struct winrt_type<winrt::Windows::UI::Core::AnimationMetrics::IPropertyAnimation>
    {
        static PyTypeObject* get_python_type() noexcept;
    };
}
