# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui.notifications

class UserNotificationListenerAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED = 2

Self = typing.TypeVar('Self')

class UserNotificationListener(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[UserNotificationListener]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserNotificationListener: ...
    def clear_notifications(self) -> None: ...
    def get_access_status(self) -> UserNotificationListenerAccessStatus: ...
    def get_notification(self, notification_id: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.ui.notifications.UserNotification]: ...
    def get_notifications_async(self, kinds: winsdk.windows.ui.notifications.NotificationKinds) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.ui.notifications.UserNotification]]: ...
    def remove_notification(self, notification_id: winsdk.system.UInt32) -> None: ...
    def request_access_async(self) -> winsdk.windows.foundation.IAsyncOperation[UserNotificationListenerAccessStatus]: ...
    def add_notification_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[UserNotificationListener, winsdk.windows.ui.notifications.UserNotificationChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_notification_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

